@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc,v 1.35 2005/12/06 16:36:02 andrewross Exp $
+// $Id: plstream.cc,v 1.38 2006/05/13 06:35:05 airwin Exp $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -339,7 +339,7 @@ plstream::svect(PLFLT *arrow_x, PLFLT *arrow_y, PLINT npts, bool fill)
     plsvect(arrow_x, arrow_y, npts, (PLBOOL) fill);
 }
 
-// Depreciated version using PLINT instead of bool
+// Deprecated version using PLINT instead of bool
 void
 plstream::svect(PLFLT *arrow_x, PLFLT *arrow_y, PLINT npts, PLINT fill)
 {
@@ -483,13 +483,6 @@ void plstream::fcont( PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 
 // /* Copies state parameters from the reference stream to the current stream. */
 
-// void plstream::cpstrm( PLINT iplsr, PLINT flags )
-// {
-//     set_stream();
-
-//     plcpstrm(iplsr,flags);
-// }
-
 void plstream::cpstrm( plstream &pls, bool flags )
 {
     set_stream();
@@ -497,7 +490,7 @@ void plstream::cpstrm( plstream &pls, bool flags )
     plcpstrm(pls.stream,(PLBOOL) flags);
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void plstream::cpstrm( plstream &pls, PLINT flags )
 {
     set_stream();
@@ -1028,12 +1021,21 @@ void plstream::surf3dl( PLFLT *x, PLFLT *y, PLFLT **z,
 
 /* Plots a 3-d representation of the function z[x][y]. */
 
+void plstream::plot3d( PLFLT *x, PLFLT *y, PLFLT **z,
+		       PLINT nx, PLINT ny, PLINT opt, bool side )
+{
+    set_stream();
+
+    ::plot3d(x,y,z,nx,ny,opt,(PLBOOL)side);
+}
+
+// Deprecated version using PLINT not bool
 void plstream::plot3d( PLFLT *x, PLFLT *y, PLFLT **z,
 		       PLINT nx, PLINT ny, PLINT opt, PLINT side )
 {
     set_stream();
 
-    ::plot3d(x,y,z,nx,ny,opt,side);
+    ::plot3d(x,y,z,nx,ny,opt,(PLBOOL)side);
 }
 
 /* Plots a 3-d representation of the function z[x][y] with contour. */
@@ -1099,19 +1101,33 @@ void plstream::poin3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT code )
 
 /* Draws a polygon in 3 space.  */
 
-void plstream::poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT *draw, bool ifcc )
+void plstream::poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, bool *draw, bool ifcc )
 {
+    PLBOOL * loc_draw = new PLBOOL[n-1];
+    for (int i=0;i<n-1;i++) {
+        loc_draw[i] = (PLBOOL) draw[i];
+    }
+    
     set_stream();
 
-    plpoly3(n,x,y,z,draw,(PLBOOL) ifcc);
+    plpoly3(n,x,y,z,loc_draw,(PLBOOL) ifcc);
+
+    delete loc_draw;
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void plstream::poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT *draw, PLINT ifcc )
 {
+    PLBOOL * loc_draw = new PLBOOL[n-1];
+    for (int i=0;i<n-1;i++) {
+        loc_draw[i] = (PLBOOL) draw[i];
+    }
+    
     set_stream();
 
-    plpoly3(n,x,y,z,draw,(PLBOOL) ifcc);
+    plpoly3(n,x,y,z,loc_draw,(PLBOOL) ifcc);
+
+    delete loc_draw;
 }
 
 /* Set the floating point precision (in number of places) in numeric labels. */
@@ -1221,8 +1237,8 @@ void plstream::scmap1l( bool itype, PLINT npts, PLFLT *intensity,
 			PLFLT *coord1, PLFLT *coord2, PLFLT *coord3,
 			bool *rev )
 {
-    PLBOOL * loc_rev = new PLBOOL[npts];
-    for (int i=0;i<npts;i++) {
+    PLBOOL * loc_rev = new PLBOOL[npts-1];
+    for (int i=0;i<npts-1;i++) {
         loc_rev[i] = (PLBOOL) rev[i];
     }
     
@@ -1233,13 +1249,13 @@ void plstream::scmap1l( bool itype, PLINT npts, PLFLT *intensity,
     delete loc_rev;
 }
 
-// Depreciated version using PLINT instead of bool
+// Deprecated version using PLINT instead of bool
 void plstream::scmap1l( PLINT itype, PLINT npts, PLFLT *intensity,
 			PLFLT *coord1, PLFLT *coord2, PLFLT *coord3,
 			PLINT *rev )
 {
-    PLBOOL * loc_rev = new PLBOOL[npts];
-    for (int i=0;i<npts;i++) {
+    PLBOOL * loc_rev = new PLBOOL[npts-1];
+    for (int i=0;i<npts-1;i++) {
         loc_rev[i] = (PLBOOL) rev[i];
     }
 
@@ -1427,7 +1443,7 @@ plstream::shade( PLFLT **a, PLINT nx, PLINT ny,
 	     fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
 
-// Depreciated version using PLINT instead of bool
+// Deprecated version using PLINT instead of bool
 void
 plstream::shade( PLFLT **a, PLINT nx, PLINT ny,
 		 PLINT (*defined) (PLFLT, PLFLT),
@@ -1466,7 +1482,7 @@ plstream::shades( PLFLT **a, PLINT nx, PLINT ny,
 	     fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
 
-// Depreciated version using PLINT instead of bool
+// Deprecated version using PLINT instead of bool
 void
 plstream::shades( PLFLT **a, PLINT nx, PLINT ny,
 		 PLINT (*defined) (PLFLT, PLFLT),
@@ -1508,7 +1524,7 @@ plstream::shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
 		Coord_Xform_evaluator, pcxf );
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void
 plstream::shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
 		 PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
@@ -1555,7 +1571,7 @@ plstream::shade1( PLFLT *a, PLINT nx, PLINT ny,
 	      fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void
 plstream::shade1( PLFLT *a, PLINT nx, PLINT ny,
 		  PLINT (*defined) (PLFLT, PLFLT),
@@ -1604,7 +1620,7 @@ plstream::fshade( PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 	      fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void
 plstream::fshade( PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 		  PLPointer f2eval_data,
@@ -1677,7 +1693,7 @@ void plstream::spause( bool pause )
     plspause((PLBOOL) pause);
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void plstream::spause( PLINT pause )
 {
     set_stream();
@@ -1748,7 +1764,7 @@ void plstream::stripc(PLINT *id, char *xspec, char *yspec,
 }
 
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void plstream::stripc(PLINT *id, char *xspec, char *yspec,
         PLFLT xmin, PLFLT xmax, PLFLT xjump, PLFLT ymin, PLFLT ymax,
         PLFLT xlpos, PLFLT ylpos,
@@ -1950,7 +1966,7 @@ void plstream::xormod(bool mode, bool *status)
    *status = (bool) loc_status;
 }
 
-// Depreciated version using PLINT not bool
+// Deprecated version using PLINT not bool
 void plstream::xormod(PLINT mode, PLINT *status)
 {
    PLBOOL loc_status;
