@@ -1,4 +1,4 @@
-/* $Id: plstubs.h,v 1.38 2005/03/14 19:41:10 airwin Exp $
+/* $Id: plstubs.h,v 1.40 2006/05/19 09:57:07 arjenmarkus Exp $
 
    Maurice LeBrun
    IFS, University of Texas
@@ -136,9 +136,9 @@
  */
 
 #define    PL_SETCONTLABELFORMAT	FNAME(PL_SETCONTLABELFORMAT,pl_setcontlabelformat)
-#define    PL_SETCONTLABELFORMATa	FNAME(PL_SETCONTLABELFORMAT,pl_setcontlabelformat_)
+#define    PL_SETCONTLABELFORMATa	FNAME(PL_SETCONTLABELFORMAT_,pl_setcontlabelformat_)
 #define    PL_SETCONTLABELPARAM		FNAME(PL_SETCONTLABELPARAM,pl_setcontlabelparam)
-#define    PL_SETCONTLABELPARAMa	FNAME(PL_SETCONTLABELPARAM,pl_setcontlabelparam_)
+#define    PL_SETCONTLABELPARAMa	FNAME(PL_SETCONTLABELPARAM_,pl_setcontlabelparam_)
 #define    PLADV	FNAME(PLADV,pladv)
 #define    PLAXES7	FNAME(PLAXES7,plaxes7)
 #define    PLBIN	FNAME(PLBIN,plbin)
@@ -146,7 +146,7 @@
 #define    PLBOX37	FNAME(PLBOX37,plbox37)
 #define    PLBOX7	FNAME(PLBOX7,plbox7)
 #define    PLCALC_WORLD 	FNAME(PLCALC_WORLD,plcalc_world)
-#define    PLCALC_WORLDa	FNAME(PLCALC_WORLD,plcalc_world_)
+#define    PLCALC_WORLDa	FNAME(PLCALC_WORLD_,plcalc_world_)
 #define    PLCLEAR	FNAME(PLCLEAR,plclear)
 #define    PLCLR	FNAME(PLCLR,plclr)
 #define    PLCOL	FNAME(PLCOL,plcol)
@@ -201,6 +201,8 @@
 #define    PLLINE	FNAME(PLLINE,plline)
 #define    PLLINE3	FNAME(PLLINE3,plline3)
 #define    PLLSTY	FNAME(PLLSTY,pllsty)
+#define    PLMAPC	FNAME(PLMAPC,plmapc)
+#define    PLMERIDIANSC	FNAME(PLMERIDIANSC,plmeridiansc)
 #define    PLMESH	FNAME(PLMESH,plmesh)
 #define    PLMESHC	FNAME(PLMESHC,plmeshc)
 #define    PLMKSTRM	FNAME(PLMKSTRM,plmkstrm)
@@ -236,6 +238,7 @@
 #define    PLSDIPLT	FNAME(PLSDIPLT,plsdiplt)
 #define    PLSDIPLZ	FNAME(PLSDIPLZ,plsdiplz)
 #define    PLSESC	FNAME(PLSESC,plsesc)
+#define    PLSETMAPFORMC	FNAME(PLSETMAPFORMC,plsetmapformc)
 #define    PLSETOPT7	FNAME(PLSETOPT7,plsetopt7)
 #define    PLSFAM	FNAME(PLSFAM,plsfam)
 #define    PLSFNAM7	FNAME(PLSFNAM7,plsfnam7)
