@@ -49,11 +49,12 @@ function [n, driver, intp]= figure (n, device, file, win_id, tk_file, plot_frame
 
   if (!exist("__pl") || !struct_contains (__pl,"inited"))
     v = split(version ,'.');
-    if (! (str2num(v(1,:)) >= 2 &&
-           str2num(v(2,:)) >= 1 &&
-           str2num(v(3,:)) >= 57))
+    if (! ((str2num(v(1,:)) > 2) ||
+           (str2num(v(1,:)) == 2 && str2num(v(2,:)) > 1) ||
+           (str2num(v(1,:)) == 2 && str2num(v(2,:)) == 1 &&
+            str2num(v(3,:)) >= 57)))
         error("The PLplot-Octave scripts need an Octave version \n\
-        greater then or equal to 2.1.57.\n");
+               greater than or equal to 2.1.57.\n");
     endif
 
     plplot_stub;
@@ -66,7 +67,7 @@ function [n, driver, intp]= figure (n, device, file, win_id, tk_file, plot_frame
 
     if (automatic_replot == 0)
       warning("It is recommended that you set 'automatic_replot=1' \n\
-	  in your ~/.octaverc file.");
+               in your ~/.octaverc file.");
       ##automatic_replot = 1;
     endif
   endif
@@ -183,7 +184,7 @@ function [n, driver, intp]= figure (n, device, file, win_id, tk_file, plot_frame
       if (strcmp("tk", sprintf("%s",plgdev')))
 	if (! exist("tk_start") && nargin == 6)
 	  error("Can't use this Tk feature of PLplot until tk_octave \
-	      is installed!\n")
+                 is installed!\n")
 	elseif (exist("tk_start"))
 	 if (!exist("__tk_name"))
 	  tk_init;
@@ -228,8 +229,9 @@ function [n, driver, intp]= figure (n, device, file, win_id, tk_file, plot_frame
 
       ## init driver and make changes apply
       plinit;
-      pladv(0);
-      plflush;pleop;
+      #next two commented. After last bop/eop CVS changes, first plot is empty.
+      #pladv(0);
+      #plflush;pleop;
       
       if ( exist("__tk_name") & (strcmp("tk", sprintf("%s",plgdev'))))
 	eval(tk_receive(1));
