@@ -1,4 +1,4 @@
-/* $Id: tclAPI.c,v 1.57 2004/06/14 21:51:52 rlaboiss Exp $
+/* $Id: tclAPI.c,v 1.60 2005/04/27 06:43:20 rlaboiss Exp $
 
     Copyright 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -21,7 +21,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 
@@ -300,7 +300,8 @@ loopbackCmd(ClientData clientData, Tcl_Interp *interp,
 
     argc--; argv++;
     if (argc == 0 || (strcmp(argv[0], "cmd") != 0)) {
-	Tcl_AppendResult(interp, "bad option to \"loopback\": must be ",
+	Tcl_AppendResult(interp, "bad option \"", argv[0],
+			 "\" to \"loopback\": must be ",
 			 "\"cmd ?options?\" ", (char *) NULL);
 	return TCL_ERROR;
     }
@@ -324,8 +325,8 @@ loopbackCmd(ClientData clientData, Tcl_Interp *interp,
 
     hPtr = Tcl_FindHashEntry(&cmdTable, argv[0]);
     if (hPtr == NULL) {
-	Tcl_AppendResult(interp,
-			 "bad option to \"loopback cmd\": must be one of ",
+	Tcl_AppendResult(interp, "bad option \"", argv[0],
+			 "\" to \"loopback cmd\": must be one of ",
 			 (char *) NULL);
 	Append_Cmdlist(interp);
 	result = TCL_ERROR;
@@ -401,7 +402,7 @@ PlbasicInit( Tcl_Interp *interp )
 /* if we are in the build tree, search there */
     if (plInBuildTree()) {
 	if (debug) fprintf(stderr, "trying BUILD_DIR\n");
-	libDir = BUILD_DIR "/bindings/tk";
+	libDir = BUILD_DIR "/bindings/tcl";
 	Tcl_SetVar(interp, "pllibrary", libDir, TCL_GLOBAL_ONLY);
 	if (Tcl_Eval(interp, initScript) != TCL_OK) {
 	    libDir = NULL;
