@@ -1,5 +1,5 @@
 ## -*-Tcl-*-
- # $Id: Pltkwin.tcl,v 1.7 2001/02/20 12:00:59 mlebrun Exp $
+ # $Id: Pltkwin.tcl,v 1.8 2005/10/31 22:31:27 mlebrun Exp $
  # ###################################################################
  # 
  #  FILE: "Pltkwin.tcl"
@@ -104,7 +104,7 @@ body Pltkwin::constructor {args} {
     } {
 	keep -background -cursor
     }
-    pack $itk_component(ftop) -side top	-fill x
+    pack $itk_component(ftop) -side top	-fill x -before $hull.plwin
 #-fill both 
 #-expand yes
     itk_component add pmenub {
