@@ -1,4 +1,4 @@
-/* $Id: plframe.c,v 1.86 2004/06/14 21:51:52 rlaboiss Exp $
+/* $Id: plframe.c,v 1.91 2005/04/27 06:43:22 rlaboiss Exp $
 
     Copyright 1993, 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -21,7 +21,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
     Based upon tkFrame.c from the TK 3.2 distribution:
@@ -47,6 +47,8 @@
 #define DEBUG
 */
 
+#define DEBUGx
+
 #define NEED_PLDEBUG
 #include "plserver.h"
 #include "plxwd.h"
@@ -513,6 +515,20 @@ PlFrameWidgetCmd(ClientData clientData, Tcl_Interp *interp,
 
     dbug_enter("PlFrameWidgetCmd");
 
+#ifdef DEBUG
+    {
+        int i;
+        PLStream *pls;
+        plgpls(pls);
+        printf( "Current stream %d, frame stream %d\n",
+                pls->ipls, plFramePtr->ipls );
+        printf( "PlFrameWidgetCmd: " );
+        for( i=0; i < argc; i++ )
+            printf( " %s", argv[i] );
+        printf( "\n" );
+    }
+#endif
+
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"",
 		argv[0], " option ?arg arg ...?\"", (char *) NULL);
@@ -522,12 +538,31 @@ PlFrameWidgetCmd(ClientData clientData, Tcl_Interp *interp,
     c = argv[1][0];
     length = strlen(argv[1]);
 
+/* First, before anything else, we have to set the stream to be the one that
+ * corresponds to this widget. */
+    plsstrm( plFramePtr->ipls );
+
 /* cmd -- issue a command to the PLplot library */
 
     if ((c == 'c') && (strncmp(argv[1], "cmd", length) == 0)) {
 	result = Cmd(interp, plFramePtr, argc-2, argv+2);
     }
 
+/* cget */
+
+    else if ((c == 'c') && (strncmp(argv[1], "cget", length) == 0)) {
+	if (argc > 2) {
+	    Tcl_AppendResult(interp, "wrong # args: should be \"",
+		    argv[0], " cget <option>\"", (char *) NULL);
+	    result = TCL_ERROR;
+	    goto done;
+	}
+	else {
+	    result = Tk_ConfigureInfo(interp, plFramePtr->tkwin, configSpecs,
+		    (char *) plFramePtr, (char *) NULL, 0);
+	}
+    }
+
 /* configure */
 
     else if ((c == 'c') && (strncmp(argv[1], "configure", length) == 0)) {
@@ -719,8 +754,15 @@ PlFrameWidgetCmd(ClientData clientData, Tcl_Interp *interp,
 	 "view, xscroll, or yscroll", (char *) NULL);
 
 	result = TCL_ERROR;
+#ifdef DEBUG
+        printf( "bad option!\n" );
+#endif
     }
 
+#ifdef DEBUG
+    printf( "result=%d current stream=%d\n", result, plsc->ipls );
+#endif
+
  done:
     Tk_Release((ClientData) plFramePtr);
     return result;
@@ -1740,7 +1782,7 @@ scol1(Tcl_Interp *interp, register PlFrame *plFramePtr,
     g = ((unsigned) (xcol.green & 0xFF00) >> 8) / 255.0;
     b = ((unsigned) (xcol.blue  & 0xFF00) >> 8) / 255.0;
 
-    plRGB_HLS(r, g, b, &h, &l, &s);
+    plrgbhls(r, g, b, &h, &l, &s);
 
     p = atof(pos) / 100.0;
     reverse = atoi(rev);
@@ -1851,7 +1893,7 @@ ColorManip(Tcl_Interp *interp, register PlFrame *plFramePtr,
 	    l = pls->cmap1cp[i].l;
 	    s = pls->cmap1cp[i].s;
 
-	    plHLS_RGB(h, l, s, &r, &g, &b);
+	    plhlsrgb(h, l, s, &r, &g, &b);
 
 	    r1 = MAX(0, MIN(255, (int) (256. * r)));
 	    g1 = MAX(0, MIN(255, (int) (256. * g)));
@@ -1931,7 +1973,8 @@ ColorManip(Tcl_Interp *interp, register PlFrame *plFramePtr,
 	}
 
 	if (changed) {
-	    plsc->ncp1 = ncp1;
+            PLStream *pls = plFramePtr->pls;
+	    pls->ncp1 = ncp1;
 	    plcmap1_calc();
 	}
     }
@@ -2609,6 +2652,8 @@ Print(Tcl_Interp *interp, register PlFrame *plFramePtr,
 
     plsdev("plmeta");
     plsfile(sfile);
+/* FIXME: plmeta/plrender need to honor these, needed to preserve the aspect ratio */
+    plspage( 0., 0., plFramePtr->width, plFramePtr->height, 0, 0 );
     plcpstrm(plFramePtr->ipls, 0);
     pladv(0);
 
@@ -2736,6 +2781,8 @@ Save(Tcl_Interp *interp, register PlFrame *plFramePtr,
 	    return TCL_ERROR;
 	}
 	plsstrm(plFramePtr->ipls_save);
+    /* Note: many drivers ignore these, needed to preserve the aspect ratio */
+        plspage( 0., 0., plFramePtr->width, plFramePtr->height, 0, 0 );
 	plcpstrm(plFramePtr->ipls, 0);
 	pladv(0);
 	plreplot();
@@ -2787,6 +2834,8 @@ Save(Tcl_Interp *interp, register PlFrame *plFramePtr,
 
 	plsdev(argv[1]);
 	plsfile(sfile);
+    /* Note: many drivers ignore these, needed to preserve the aspect ratio */
+        plspage( 0., 0., plFramePtr->width, plFramePtr->height, 0, 0 );
 	plcpstrm(plFramePtr->ipls, 0);
 	pladv(0);
 
