@@ -1,4 +1,4 @@
-/* $Id: plmeta.c,v 1.41 2004/01/19 19:10:19 airwin Exp $
+/* $Id: plmeta.c,v 1.43 2005/02/28 11:35:19 mlebrun Exp $
 
     Copyright 1991, 1992, 1993, 1994, 1995
     Geoffrey Furnish			furnish@dino.ph.utexas.edu
@@ -539,7 +539,7 @@ plD_state_plm(PLStream *pls, PLINT op)
 	break;
 
     case PLSTATE_COLOR0:
-	plm_wr( pdf_wr_1byte(pls->pdfs, (U_CHAR) pls->icol0) );
+	plm_wr( pdf_wr_2bytes(pls->pdfs, (short) pls->icol0) );
 
 	if (pls->icol0 == PL_RGB_COLOR) {
 	    plm_wr( pdf_wr_1byte(pls->pdfs, pls->curcolor.r) );
@@ -557,7 +557,7 @@ plD_state_plm(PLStream *pls, PLINT op)
 	break;
 
     case PLSTATE_CMAP0:
-	plm_wr( pdf_wr_1byte(pls->pdfs, (U_CHAR) pls->ncol0) );
+	plm_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->ncol0) );
 	for (i = 0; i < pls->ncol0; i++) {
 	    plm_wr( pdf_wr_1byte(pls->pdfs, pls->cmap0[i].r) );
 	    plm_wr( pdf_wr_1byte(pls->pdfs, pls->cmap0[i].g) );
@@ -696,6 +696,28 @@ WriteFileHeader(PLStream *pls)
     plm_wr( pdf_wr_header(pls->pdfs, "pxly") );
     plm_wr( pdf_wr_ieeef(pls->pdfs, (float) dev->pxly) );
 
+/* Geometry info, needed to properly transmit e.g. aspect ratio, via the
+   length params.  Not sure if the others are useful, but they're included for
+   completeness. */ 
+
+    plm_wr( pdf_wr_header(pls->pdfs, "xdpi") );
+    plm_wr( pdf_wr_ieeef(pls->pdfs, (float) pls->xdpi) );
+
+    plm_wr( pdf_wr_header(pls->pdfs, "ydpi") );
+    plm_wr( pdf_wr_ieeef(pls->pdfs, (float) pls->ydpi) );
+
+    plm_wr( pdf_wr_header(pls->pdfs, "xlength") );
+    plm_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->xlength) );
+
+    plm_wr( pdf_wr_header(pls->pdfs, "ylength") );
+    plm_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->ylength) );
+
+    plm_wr( pdf_wr_header(pls->pdfs, "xoffset") );
+    plm_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->xoffset) );
+
+    plm_wr( pdf_wr_header(pls->pdfs, "yoffset") );
+    plm_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->yoffset) );
+
     plm_wr( pdf_wr_header(pls->pdfs, "") );
 }
 
