@@ -1,4 +1,4 @@
-/* $Id: tk.c,v 1.87 2004/06/14 21:51:53 rlaboiss Exp $
+/* $Id: tk.c,v 1.91 2005/04/27 06:43:48 rlaboiss Exp $
  *
  *	PLplot Tcl/Tk and Tcl-DP device drivers.
  *	Should be broken up somewhat better to allow use of DP w/o X.
@@ -24,7 +24,7 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
@@ -229,12 +229,14 @@ init(PLStream *pls)
     pls->dev_fill1 = 1;		/* Handle pattern fills */
     pls->server_nokill = 1;     /* don't kill if ^C */
     pls->dev_xor = 1;           /* device support xor mode */
-    pls->plbuf_write = 1;       /* Activate plot buffer. To
-    programmatically save a file we can't call plreplot(), but instead
-    one must send a command to plserver. As there is no API call for
-    this, the user must use the plserver "save/print" menu
-    entries. Activating the plot buffer enables the normal
-    plmkstrm/plcpstrm/plreplot/plend1 way of saving plots. */
+
+/* Activate plot buffer. To programmatically save a file we can't call
+   plreplot(), but instead one must send a command to plserver. As there is
+   no API call for this, the user must use the plserver "save/print" menu
+   entries. Activating the plot buffer enables the normal
+   plmkstrm/plcpstrm/plreplot/plend1 way of saving plots.
+*/
+    pls->plbuf_write = 1;
 
 /* Specify buffer size if not yet set (can be changed by -bufmax option).  */
 /* A small buffer works best for socket communication */
@@ -313,10 +315,8 @@ init(PLStream *pls)
     tk_wr_header(pls, "");
 
 /* Write color map state info */
-/*
-    plD_state_plm(pls, PLSTATE_CMAP0);
-    plD_state_plm(pls, PLSTATE_CMAP1);
-    */
+    plD_state_tk(pls, PLSTATE_CMAP0);
+    plD_state_tk(pls, PLSTATE_CMAP1);
 
 /* Good place to make sure the data transfer is working OK */
 
@@ -471,7 +471,8 @@ plD_state_tk(PLStream *pls, PLINT op)
 	break;
 
     case PLSTATE_COLOR0:
-	tk_wr( pdf_wr_1byte(pls->pdfs, (U_CHAR) pls->icol0) );
+	tk_wr( pdf_wr_2bytes(pls->pdfs, (short) pls->icol0) );
+
 	if (pls->icol0 == PL_RGB_COLOR) {
 	    tk_wr( pdf_wr_1byte(pls->pdfs, pls->curcolor.r) );
 	    tk_wr( pdf_wr_1byte(pls->pdfs, pls->curcolor.g) );
@@ -488,7 +489,7 @@ plD_state_tk(PLStream *pls, PLINT op)
 	break;
 
     case PLSTATE_CMAP0:
-	tk_wr( pdf_wr_1byte(pls->pdfs, (U_CHAR) pls->ncol0) );
+	tk_wr( pdf_wr_2bytes(pls->pdfs, (U_SHORT) pls->ncol0) );
 	for (i = 0; i < pls->ncol0; i++) {
 	    tk_wr( pdf_wr_1byte(pls->pdfs, pls->cmap0[i].r) );
 	    tk_wr( pdf_wr_1byte(pls->pdfs, pls->cmap0[i].g) );
