@@ -1,4 +1,4 @@
-/* $Id: wingcc.c,v 1.2 2004/05/30 05:02:05 aroach Exp $
+/* $Id: wingcc.c,v 1.13 2005/12/24 14:02:30 arjenmarkus Exp $
 
 	PLplot WIN32 under GCC device driver.
 
@@ -18,18 +18,19 @@
 
    You should have received a copy of the GNU Library General Public License
    along with PLplot; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 */
 #include "plDevs.h"
 
 #ifdef PLD_wingcc
 
+#include <string.h>
+#include <windows.h>
+
 #include "plplotP.h"
 #include "drivers.h"
 #include "plevent.h"
-#include <string.h>
-#include <windows.h>
 
 #ifdef HAVE_FREETYPE
 
@@ -61,7 +62,7 @@
 
 /* Device info */
 
-char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:5:wingcc";
+char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:9:wingcc";
 
 /* Struct to hold device-specific info. */
 
@@ -75,15 +76,21 @@ typedef struct {
  */
 
     COLORREF      colour;              /* Current Colour               */
+    COLORREF      oldcolour;           /* Used for high-speed background erasing */
     MSG		      msg;		            /* A Win32 message structure. */
     WNDCLASSEX	   wndclass;	         /* An extended window class structure. */
     HWND          hwnd;                /* Handle for the main window. */
     HPEN          pen;                 /* Windows pen used for drawing */
     HDC           hdc;                 /* Driver Context */
+    HDC           hdc2;                /* Driver Context II - used for Blitting */
     PAINTSTRUCT   ps;                  /* used to paint the client area of a window owned by that application */
     RECT		      rect;                /* defines the coordinates of the upper-left and lower-right corners of a rectangle */
-    HBRUSH        bgbrush;             /* brush used for filling the background */
+    RECT		      oldrect;             /* used for re-sizing comparisons */
+    RECT		      paintrect;           /* used for painting etc... */
+    HBRUSH        fillbrush;           /* brush used for fills */
     HCURSOR       cursor;              /* Current windows cursor for this window */
+    HBITMAP       bitmap;              /* Bitmap of current display; used for fast redraws via blitting */
+    HGDIOBJ       oldobject;           /* Used for tracking objects probably not really needed but */
 
     PLINT         draw_mode;
     char          truecolour;          /* Flag to indicate 24 bit mode */
@@ -91,6 +98,7 @@ typedef struct {
                                        /* we only do a windows redraw if plplot is plotting */
     char          enterresize;         /* Used to keep track of reszing messages from windows */
     char          resize;              /* When "entersize" is set and "reszie" isnt, user maximised the window */
+    char          already_erased;      /* Used to track first and only first backgroudn erases */
 
   } wingcc_Dev;
 
@@ -117,7 +125,6 @@ extern void plD_FreeType_init(PLStream *pls);
 extern void plD_render_freetype_text (PLStream *pls, EscText *args);
 extern void plD_FreeType_Destroy(PLStream *pls);
 extern void pl_set_extended_cmap0(PLStream *pls, int ncol0_width, int ncol0_org);
-extern void pl_RemakeFreeType_text_from_buffer (PLStream *pls);
 #endif
 
 
@@ -129,6 +136,7 @@ static int GetRegValue(char *key_name, char *key_word, char *buffer, int size);
 static int SetRegValue(char *key_name, char *key_word, char *buffer,int dwType, int size);
 static void Resize ( PLStream *pls );
 static void plD_fill_polygon_wingcc(PLStream *pls);
+static void CopySCRtoBMP(PLStream *pls);
 
 #define SetRegStringValue(a,b,c) SetRegValue(a, b, c, REG_SZ, strlen(c)+1 )
 #define SetRegBinaryValue(a,b,c,d) SetRegValue(a, b, (char *)c, REG_BINARY, d )
@@ -153,6 +161,11 @@ MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),(LPTSTR) &lpMsgBuf, 0, NULL ); \
 MessageBox( NULL, lpMsgBuf, "GetLastError", MB_OK|MB_ICONINFORMATION ); \
 LocalFree( lpMsgBuf );}while(0)
 
+#define CrossHairCursor() do { \
+dev->cursor = LoadCursor(NULL,IDC_CROSS); \
+SetClassLong(dev->hwnd,GCL_HCURSOR,(long)dev->cursor); \
+SetCursor(dev->cursor);}while(0)
+
 #define NormalCursor() do { \
 dev->cursor = LoadCursor(NULL,IDC_ARROW); \
 SetClassLong(dev->hwnd,GCL_HCURSOR,(long)dev->cursor); \
@@ -171,7 +184,7 @@ void plD_dispatch_init_wingcc( PLDispatchTable *pdt )
     pdt->pl_DevName  = "wingcc";
 #endif
     pdt->pl_type     = plDevType_Interactive;
-    pdt->pl_seq      = 5;
+    pdt->pl_seq      = 9;
     pdt->pl_init     = (plD_init_fp)     plD_init_wingcc;
     pdt->pl_line     = (plD_line_fp)     plD_line_wingcc;
     pdt->pl_polyline = (plD_polyline_fp) plD_polyline_wingcc;
@@ -197,7 +210,7 @@ LRESULT CALLBACK PlplotWndProc (HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
   wingcc_Dev *dev = NULL;
 
 /*
- * The window carries a 32bit user defined pointer which points to the 
+ * The window carries a 32bit user defined pointer which points to the
  * plplot stream (pls). This is used for tracking the window.
  * Unfortunately, this is "attached" to the window AFTER it is created
  * so we can not initialise PLStream or wingcc_Dev "blindly" because
@@ -222,7 +235,7 @@ LRESULT CALLBACK PlplotWndProc (HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
 /*
  * Process the windows messages
  *
- * Everything except WM_CREATE is done here and it is generally hoped that 
+ * Everything except WM_CREATE is done here and it is generally hoped that
  * pls and dev are defined already by this stage.
  * That will be true MOST of the time. Some times WM_PAINT will be called
  * before we get to initialise the user data area of the window with the
@@ -242,18 +255,29 @@ LRESULT CALLBACK PlplotWndProc (HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
         if (dev)
           {
           	Debug("WM_PAINT\t");
-            if (GetUpdateRect(hwnd,&dev->rect,TRUE))
+            if (GetUpdateRect(dev->hwnd,&dev->paintrect,TRUE))
               {
               	 BusyCursor();
-                BeginPaint (hwnd, &dev->ps);
-                if (dev->waiting==1)
-                {
-                    plRemakePlot(pls);
-                    #ifdef HAVE_FREETYPE
-                    pl_RemakeFreeType_text_from_buffer(pls);
-                    #endif
-                 }
-                EndPaint (hwnd, &dev->ps);
+                BeginPaint (dev->hwnd, &dev->ps);
+
+                if ((dev->waiting==1)&&(dev->already_erased==1))
+                  {
+                    Debug("Remaking\t");
+                      plRemakePlot(pls);
+                      CopySCRtoBMP(pls);
+                      dev->already_erased++;
+                   }
+                else if ((dev->waiting==1)&&(dev->already_erased==2))
+                  {
+                    dev->oldobject = SelectObject(dev->hdc2,dev->bitmap);
+/*                    BitBlt(dev->hdc,0,0,dev->rect.right,dev->rect.bottom,dev->hdc2,0,0,SRCCOPY); */
+                    BitBlt(dev->hdc,dev->paintrect.left,dev->paintrect.top,
+                           dev->paintrect.right,dev->paintrect.bottom,
+                           dev->hdc2,dev->paintrect.left,dev->paintrect.top,SRCCOPY);
+                    SelectObject(dev->hdc2,dev->oldobject);
+                  }
+
+                EndPaint (dev->hwnd, &dev->ps);
                 NormalCursor();
          		 return(0);
               }
@@ -298,12 +322,34 @@ LRESULT CALLBACK PlplotWndProc (HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
       case WM_ERASEBKGND:
       if (dev)
         {
-          Debug("WM_ERASEBKGND\t");
+          if (dev->already_erased==0)
+          {
+           Debug("WM_ERASEBKGND\t");
+
+          /*
+           *    This is a new "High Speed" way of filling in the background.
+           *    supposidely this executes faster than creating a brush and
+           *    filling a rectangle - go figure ?
+           */
+/*          GetClientRect(dev->hwnd,&dev->rect); */
+           dev->oldcolour = SetBkColor(dev->hdc, RGB(pls->cmap0[0].r,pls->cmap0[0].g,pls->cmap0[0].b));
+           ExtTextOut(dev->hdc, 0, 0, ETO_OPAQUE, &dev->rect, "", 0, 0);
+           SetBkColor(dev->hdc, dev->oldcolour);
+
+          /*
+           *   This is the old "low speed" way of filling the background
+
+
           dev->bgbrush = CreateSolidBrush(RGB(pls->cmap0[0].r,pls->cmap0[0].g,pls->cmap0[0].b));
-          GetClientRect(hwnd,&dev->rect);
+          GetClientRect(dev->hwnd,&dev->rect);
           SelectObject (dev->hdc, dev->bgbrush);
           FillRect(dev->hdc, &dev->rect,dev->bgbrush);
           DeleteObject (dev->bgbrush);
+
+          */
+           dev->already_erased=1;
+          }
+
           return(1);
         }
         return(0);
@@ -333,16 +379,28 @@ void
 plD_init_wingcc(PLStream *pls)
 {
     wingcc_Dev *dev;
+
 #ifdef HAVE_FREETYPE
-    int freetype=0;
-    int smooth_text=0;
+    static int freetype=0;
+    static int smooth_text=0;
+    static int save_reg=0;
     FT_Data *FT;
+
+/*
+ *  Variables used for reading the registary keys
+ *  might eventually add a user defined pallette here, but for now it just does freetype
+ */
+    char key_name[]="Software\\PLplot\\wingcc";
+    char Keyword_text[]="freetype";
+    char Keyword_smooth[]="smooth";
 #endif
 
     DrvOpt wingcc_options[] = {
 #ifdef HAVE_FREETYPE
                               	{"text", DRV_INT, &freetype, "Use driver text (FreeType)"},
                               {"smooth", DRV_INT, &smooth_text, "Turn text smoothing on (1) or off (0)"},
+                              {"save", DRV_INT, &save_reg, "Save defaults to registary"},
+
 #endif
 			      {NULL, DRV_INT, NULL, NULL}};
 
@@ -370,10 +428,38 @@ plD_init_wingcc(PLStream *pls)
     if (!pls->colorset)
 	pls->color = 1;
 
+
+#ifdef HAVE_FREETYPE
+
+/*
+ *  Read registry to see if the user has set up default values
+ *  for text and smoothing. These will be overriden by anything that
+ *  might be given on the command line, so we will load the
+ *  values right into the same memory slots we pass to plParseDrvOpts
+ */
+
+    GetRegIntValue(key_name, Keyword_text, &freetype);
+    GetRegIntValue(key_name, Keyword_smooth, &smooth_text);
+
+#endif
+
 /* Check for and set up driver options */
 
     plParseDrvOpts(wingcc_options);
 
+#ifdef HAVE_FREETYPE
+
+/*
+ *  We will now save the settings to the registary if the user wants
+ */
+
+    if (save_reg==1)
+      {
+        SetRegIntValue(key_name, Keyword_text, &freetype);
+        SetRegIntValue(key_name, Keyword_smooth, &smooth_text);
+      }
+
+#endif
 
 /* Set up device parameters */
 
@@ -434,8 +520,8 @@ plD_init_wingcc(PLStream *pls)
                                   szWndClass,               /* Class name */
                                   pls->program,             /* Caption */
                                   WS_OVERLAPPEDWINDOW,      /* Style */
-                                  CW_USEDEFAULT,            /* Initial x (use default) */
-                                  CW_USEDEFAULT,            /* Initial y (use default) */
+                                  pls->xoffset,            /* Initial x (use default) */
+                                  pls->yoffset,            /* Initial y (use default) */
                                   pls->xlength,             /* Initial x size (use default) */
                                   pls->ylength,             /* Initial y size (use default) */
                                   NULL,                     /* No parent window */
@@ -458,7 +544,8 @@ dev->hdc = GetDC (dev->hwnd);
 
 if (freetype)
    {
-    pls->dev_text = 1; /* want to draw text */
+    pls->dev_text = 1;     /* want to draw text */
+    pls->dev_unicode = 1;  /* want unicode */
     init_freetype_lv1(pls);
     FT=(FT_Data *)pls->FT;
     FT->want_smooth_text=smooth_text;
@@ -484,7 +571,7 @@ plD_state_wingcc(pls, PLSTATE_COLOR0);
 
      if (pls->xdpi<=0) /* Get DPI from windows */
      {
-        plspage(GetDeviceCaps(dev->hdc,HORZRES)/GetDeviceCaps(dev->hdc,HORZSIZE)*25.4,
+         plspage(GetDeviceCaps(dev->hdc,HORZRES)/GetDeviceCaps(dev->hdc,HORZSIZE)*25.4,
          GetDeviceCaps(dev->hdc,VERTRES)/GetDeviceCaps(dev->hdc,VERTSIZE)*25.4, 0, 0, 0, 0);
      }
      else
@@ -501,6 +588,7 @@ plD_state_wingcc(pls, PLSTATE_COLOR0);
  */
 
   	 GetClientRect(dev->hwnd,&dev->rect);
+/*    GetClipBox(dev->hdc,&dev->rect); */
     dev->width=dev->rect.right;
     dev->height=dev->rect.bottom;
 
@@ -540,12 +628,15 @@ plD_line_wingcc(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
   wingcc_Dev *dev=(wingcc_Dev *)pls->dev;
   POINT points[2];
 
+
   points[0].x=x1a/dev->scale;
   points[1].x=x2a/dev->scale;
   points[0].y=dev->height - (y1a/dev->scale);
   points[1].y=dev->height - (y2a/dev->scale);
 
+  dev->oldobject = SelectObject (dev->hdc, dev->pen);
   Polyline(dev->hdc, points,2);
+  SelectObject (dev->hdc, dev->oldobject);
 
 }
 
@@ -573,7 +664,9 @@ plD_polyline_wingcc(PLStream *pls, short *xa, short *ya, PLINT npts)
               points[i].x =  (unsigned long) xa[i]/dev->scale;
               points[i].y =  (unsigned long) dev->height - (ya[i]/dev->scale);
             }
+          dev->oldobject = SelectObject (dev->hdc, dev->pen);
           Polyline(dev->hdc,points,npts);
+          SelectObject (dev->hdc, dev->oldobject);
           GlobalFree(points);
         }
       else
@@ -610,20 +703,53 @@ plD_fill_polygon_wingcc(PLStream *pls)
           points[i].y = dev->height -(pls->dev_y[i]/dev->scale);
         }
 
-      dev->bgbrush = CreateSolidBrush(dev->colour);
-      SelectObject (dev->hdc, dev->bgbrush);
+      dev->fillbrush = CreateSolidBrush(dev->colour);
+      dev->oldobject = SelectObject (dev->hdc, dev->fillbrush);
       Polygon(dev->hdc,points,pls->dev_npts);
-      DeleteObject (dev->bgbrush);
+      SelectObject (dev->hdc, dev->oldobject);
+      DeleteObject (dev->fillbrush);
       GlobalFree(points);
     }
 }
 
+/*--------------------------------------------------------------------------*\
+ *    static void CopySCRtoBMP(PLStream *pls)
+ *       Function copies the screen contents into a bitmap which is
+ *       later used for fast redraws of the screen (when it gets corrupted)
+ *       rather than remaking the plot from the plot buffer.
+\*--------------------------------------------------------------------------*/
+
+static void CopySCRtoBMP(PLStream *pls)
+{
+  wingcc_Dev *dev=(wingcc_Dev *)pls->dev;
+  RECT rect;
+
+  /*
+   *   Clean up the old bitmap and DC
+   */
+
+  if (dev->hdc2!=NULL) DeleteDC(dev->hdc2);
+  if (dev->bitmap!=NULL) DeleteObject(dev->bitmap);
+
+  dev->hdc2=CreateCompatibleDC(dev->hdc);
+/*  GetClipBox(dev->hdc,&rect);
+  GetClientRect(dev->hwnd,&dev->rect); */
+  dev->bitmap=CreateCompatibleBitmap(dev->hdc,dev->rect.right,dev->rect.bottom);
+  dev->oldobject=SelectObject(dev->hdc2,dev->bitmap);
+  BitBlt(dev->hdc2,0,0,rect.right,rect.bottom,dev->hdc,0,0,SRCCOPY);
+  SelectObject(dev->hdc2,dev->oldobject);
+}
+
+
+
 void
 plD_eop_wingcc(PLStream *pls)
 {
   wingcc_Dev *dev=(wingcc_Dev *)pls->dev;
 
   Debug("End of the page\n");
+  CopySCRtoBMP(pls);
+  dev->already_erased=2;
 
   NormalCursor();
 
@@ -675,20 +801,16 @@ plD_bop_wingcc(PLStream *pls)
 #ifdef HAVE_FREETYPE
   FT_Data *FT=(FT_Data *)pls->FT;
 #endif
-
   Debug("Start of Page\t");
 
 /*
  *  Turn the cursor to a busy sign, clear the page by "invalidating" it
- *  reset freetype, if we have to, then reset the colours and pen width
+ *  then reset the colours and pen width
  */
 
   BusyCursor();
-  RedrawWindow(dev->hwnd,NULL,NULL,RDW_ERASE|RDW_INVALIDATE);
-
-#ifdef HAVE_FREETYPE
- pl_FreeTypeBOP();
-#endif
+  dev->already_erased=0;
+  RedrawWindow(dev->hwnd,NULL,NULL,RDW_ERASE|RDW_INVALIDATE|RDW_ERASENOW);
 
   plD_state_wingcc(pls, PLSTATE_COLOR0);
 }
@@ -696,7 +818,6 @@ plD_bop_wingcc(PLStream *pls)
 void
 plD_tidy_wingcc(PLStream *pls)
 {
-  wingcc_Dev *dev=(wingcc_Dev *)pls->dev;
 
 #ifdef HAVE_FREETYPE
   if (pls->dev_text)
@@ -742,7 +863,6 @@ plD_state_wingcc(PLStream *pls, PLINT op)
 
   if (dev->pen!=NULL) DeleteObject(dev->pen);
   dev->pen=CreatePen( PS_SOLID, pls->width,dev->colour);
-  SelectObject (dev->hdc, dev->pen);
 }
 
 void
@@ -773,6 +893,11 @@ plD_esc_wingcc(PLStream *pls, PLINT op, void *ptr)
      case PLESC_HAS_TEXT:
         plD_render_freetype_text(pls, (EscText *)ptr);
         break;
+
+/*     case PLESC_LIKES_UNICODE:
+        plD_render_freetype_sym(pls, (EscText *)ptr);
+        break;*/
+
 #endif
 
       }
@@ -798,33 +923,46 @@ static void Resize( PLStream *pls )
 #ifdef HAVE_FREETYPE
   FT_Data *FT=(FT_Data *)pls->FT;
 #endif
+   Debug("Resizing");
 
  	if (dev->waiting==1)     /* Only resize the window IF plplot has finished with it */
   	{
-   	GetClientRect(dev->hwnd,&dev->rect);
-   	if ((dev->rect.right>0)&&(dev->rect.bottom>0))
+  	   memcpy(&dev->oldrect,&dev->rect,sizeof(RECT));
+/*   	GetClipBox(dev->hdc,&dev->rect); */                 /* Find out how big the region is NOW */
+      GetClientRect(dev->hwnd,&dev->rect);
+      Debug("[%d %d]",dev->rect.right,dev->rect.bottom);
+   	if ((dev->rect.right>0)&&(dev->rect.bottom>0))    /* Check to make sure it isn't just minimised (i.e. zero size) */
         {
-          dev->width=dev->rect.right;
-          dev->height=dev->rect.bottom;
-          if (dev->width>dev->height)           /* Work out the scaling factor for the  */
-            {                                   /* "virtual" (oversized) page           */
-              dev->scale=(PLFLT)PIXELS_X/dev->width;
-            }
-          else
+          if (memcmp(&dev->rect,&dev->oldrect,sizeof(RECT))!=0)   /* See if the window's changed size or not */
             {
-              dev->scale=(PLFLT)PIXELS_Y/dev->height;
-            }
+              dev->already_erased=0;
+              dev->width=dev->rect.right;
+              dev->height=dev->rect.bottom;
+              if (dev->width>dev->height)           /* Work out the scaling factor for the  */
+                {                                   /* "virtual" (oversized) page           */
+                  dev->scale=(PLFLT)PIXELS_X/dev->width;
+                }
+              else
+                {
+                  dev->scale=(PLFLT)PIXELS_Y/dev->height;
+                }
 
 #ifdef HAVE_FREETYPE
-          if (FT)
-            {
-              FT->scale=dev->scale;
-              FT->ymax=dev->height;
-            }
+              if (FT)
+                {
+                  FT->scale=dev->scale;
+                  FT->ymax=dev->height;
+                }
 #endif
-
-          RedrawWindow(dev->hwnd,NULL,NULL,RDW_INVALIDATE|RDW_ERASE);
+           }
+          RedrawWindow(dev->hwnd,NULL,NULL,RDW_INVALIDATE|RDW_ERASE|RDW_ERASENOW);
+          SendMessage(dev->hwnd,WM_PAINT,0,0);
+          dev->already_erased=2;
         }
+       else
+         {
+           memcpy(&dev->rect,&dev->oldrect,sizeof(RECT)); /* restore the old size to current size since the window is minimised */
+         }
      }
 }
 
@@ -840,10 +978,10 @@ static void Resize( PLStream *pls )
 static int SetRegValue(char *key_name, char *key_word, char *buffer,int dwType, int size)
 {
   int j=0;
-  
+
   DWORD lpdwDisposition;
   HKEY hKey;
-  
+
   j=RegCreateKeyEx(
                     HKEY_CURRENT_USER,
                     key_name,
@@ -944,7 +1082,7 @@ FT=(FT_Data *)pls->FT;
 
 x=GetDeviceCaps(dev->hdc,RASTERCAPS);
 
-if (x&&RC_BITBLT)
+if (x & RC_BITBLT)
   FT->pixel= (plD_pixel_fp)plD_pixelV_wingcc;
 else
   FT->pixel= (plD_pixel_fp)plD_pixel_wingcc;
