@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x08.cc,v 1.15 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x08.cc,v 1.16 2006/05/27 21:50:26 hbabcock Exp $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -152,7 +152,7 @@ x08::x08( int argc, char **argv ) {
   bool rosen = true;
 
   PLFLT xx, yy, r;
-  PLFLT zmin, zmax;
+  PLFLT zmin = 0.0, zmax = 0.0;
 
   int ifshade;
 
