@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x22.cc,v 1.14 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x22.cc,v 1.15 2006/05/13 06:44:43 airwin Exp $
 //    Simple vector plot example
 //---------------------------------------------------------------------------//
 //
@@ -295,7 +295,7 @@ x22::x22( int argc, char ** argv ) {
 
     // Set arrow style using arrow2_x and arrow2_y then 
     // plot using these filled arrows.
-    fill = 1;
+    fill = true;
     pls->svect(arrow2_x, arrow2_y, narr, fill);
     constriction();
 
