@@ -1,4 +1,4 @@
-/* $Id: x01c.c,v 1.39 2004/06/17 06:43:57 rlaboiss Exp $
+/* $Id: x01c.c,v 1.42 2005/10/07 17:53:37 airwin Exp $
 
 	Simple line plot and multiple windows demo.
 
@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU Library General Public License
   along with PLplot; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 */
 
@@ -118,7 +118,7 @@ main(int argc, char *argv[])
 /* Parse and process command line arguments */
 
     plMergeOpts(options, "x01c options", notes);
-    plParseOpts(&argc, argv, PL_PARSE_FULL);
+    plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Get version number, just for kicks */
 
@@ -347,7 +347,7 @@ plot3(void)
 
     for (i = 0; i < 101; i++) {
 	x[i] = 3.6 * i;
-	y[i] = sin(x[i] * PI / 180.0);
+	y[i] = sin(x[i] * M_PI / 180.0);
     }
 
     plcol0(4);
