@@ -1,4 +1,4 @@
-/* $Id: x04c.c,v 1.17 2002/12/03 08:39:24 airwin Exp $
+/* $Id: x04c.c,v 1.19 2005/10/07 17:53:37 airwin Exp $
 
 	Log plot demo.
 */
@@ -18,7 +18,7 @@ main(int argc, char *argv[])
 {
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
@@ -56,7 +56,7 @@ plot1(int type)
 	freql[i] = -2.0 + i / 20.0;
 	freq = pow(10.0, freql[i]);
 	ampl[i] = 20.0 * log10(1.0 / sqrt(1.0 + pow((freq / f0), 2.)));
-	phase[i] = -(180.0 / PI) * atan(freq / f0);
+	phase[i] = -(180.0 / M_PI) * atan(freq / f0);
     }
 
     plvpor(0.15, 0.85, 0.1, 0.9);
