@@ -1,4 +1,4 @@
-/* $Id: x05c.c,v 1.15 2002/12/03 08:39:24 airwin Exp $
+/* $Id: x05c.c,v 1.17 2005/10/07 17:53:37 airwin Exp $
 
 	Histogram demo.
 */
@@ -21,7 +21,7 @@ main(int argc, char *argv[])
 
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
@@ -29,7 +29,7 @@ main(int argc, char *argv[])
 
 /* Fill up data points */
 
-    delta = 2.0 * PI / (double) NPTS;
+    delta = 2.0 * M_PI / (double) NPTS;
     for (i = 0; i < NPTS; i++)
 	data[i] = sin(i * delta);
 
