@@ -1,4 +1,4 @@
-/* $Id: x06c.c,v 1.15 2002/12/03 08:39:24 airwin Exp $
+/* $Id: x06c.c,v 1.17 2005/04/05 19:16:15 airwin Exp $
 
 	Font demo.
 */
@@ -20,7 +20,7 @@ main(int argc, char *argv[])
 
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
@@ -36,7 +36,7 @@ main(int argc, char *argv[])
 
 /* Draw the grid using plbox */
 
-    plbox("bcgt", 0.1, 0, "bcgt", 0.1, 0);
+    plbox("bcg", 0.1, 0, "bcg", 0.1, 0);
 
 /* Write the digits below the frame */
 
