@@ -1,4 +1,4 @@
-/* $Id: x09c.c,v 1.27 2004/06/14 21:51:54 rlaboiss Exp $
+/* $Id: x09c.c,v 1.30 2005/10/07 17:53:37 airwin Exp $
 
 	Contour plot demo.
 
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU Library General Public License
    along with PLplot; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 */
 
@@ -69,7 +69,7 @@ static void polar()
        
 /*Perimeter*/
    for (i = 0; i < PERIMETERPTS; i++) {
-      t = (2.*PI/(PERIMETERPTS-1))*(double)i;
+      t = (2.*M_PI/(PERIMETERPTS-1))*(double)i;
       px[i] = cos(t);
       py[i] = sin(t);
    }
@@ -85,7 +85,7 @@ static void polar()
    for (i = 0; i < RPTS; i++) {
       r = i/(double)(RPTS-1);
       for (j = 0; j < THETAPTS; j++) {
-	 theta = (2.*PI/(double)(THETAPTS-1))*(double)j;
+	 theta = (2.*M_PI/(double)(THETAPTS-1))*(double)j;
 	 cgrid2.xg[i][j] = r*cos(theta);
 	 cgrid2.yg[i][j] = r*sin(theta);
 	 z[i][j] = r;
@@ -154,7 +154,7 @@ static void potential()
    for (i = 0; i < PRPTS; i++) {
       r = 0.5 + (double) i;
       for (j = 0; j < PTHETAPTS; j++) {
-	 theta = (2.*PI/(double)(PTHETAPTS-1))*(0.5 + (double) j);
+	 theta = (2.*M_PI/(double)(PTHETAPTS-1))*(0.5 + (double) j);
 	 cgrid2.xg[i][j] = r*cos(theta);
 	 cgrid2.yg[i][j] = r*sin(theta);
       }
@@ -249,7 +249,7 @@ static void potential()
 		 
    /* Draw outer boundary  */
    for (i = 0; i < PPERIMETERPTS; i++) {
-      t = (2.*PI/(PPERIMETERPTS-1))*(double)i;
+      t = (2.*M_PI/(PPERIMETERPTS-1))*(double)i;
       px[i] = x0 + rmax*cos(t);
       py[i] = y0 + rmax*sin(t);
    }
@@ -286,7 +286,7 @@ main(int argc, char *argv[])
 
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
@@ -322,8 +322,8 @@ main(int argc, char *argv[])
 	for (j = 0; j < YPTS; j++) {
 	    mypltr((PLFLT) i, (PLFLT) j, &xx, &yy, NULL);
 
-	    argx = xx * PI/2;
-	    argy = yy * PI/2;
+	    argx = xx * M_PI/2;
+	    argy = yy * M_PI/2;
 	    distort = 0.4;
 
 	    cgrid1.xg[i] = xx + distort * cos(argx);
