@@ -1,4 +1,4 @@
-/* $Id: x17c.c,v 1.20 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x17c.c,v 1.21 2006/05/27 20:46:43 hbabcock Exp $
 
  * Plots a simple stripchart with four pens.
  */
@@ -27,11 +27,11 @@ static char errmsg[160];
 int
 main(int argc, char *argv[])
 {
-    PLINT id1, id2, n, autoy, acc, nsteps = 1000;
+    PLINT id1, n, autoy, acc, nsteps = 1000;
     PLFLT y1, y2, y3, y4, ymin, ymax, xlab, ylab;
     PLFLT t, tmin, tmax, tjump, dt, noise;
     PLINT colbox, collab, colline[4], styline[4];
-    char *legline[4], toplab[20];
+    char *legline[4];
 
 /* plplot initialization */
 /* Parse and process command line arguments */
