@@ -1,4 +1,4 @@
-/* $Id: x18c.c,v 1.23 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x18c.c,v 1.24 2006/05/27 20:59:50 hbabcock Exp $
 
 	3-d line and point plot demo.  Adapted from x08c.c.
 */
@@ -23,7 +23,7 @@ void test_poly(int k);
 int
 main(int argc, char *argv[])
 {
-    int i, j, k;
+    int i, k;
     PLFLT *x, *y, *z;
     PLFLT r;
     char title[80];
