@@ -1,4 +1,4 @@
-/* $Id: x21c.c,v 1.18 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x21c.c,v 1.19 2006/05/27 21:04:07 hbabcock Exp $
 	Grid data demo
 
    Copyright (C) 2004  Joao Cardoso
@@ -149,7 +149,7 @@ int
 main(int argc, char *argv[])
 {
   PLFLT *x, *y, *z, *clev;
-  PLFLT *xg, *yg, **zg, **szg;
+  PLFLT *xg, *yg, **zg;
   PLFLT zmin, zmax, lzm, lzM;
   long ct;
   int i, j, k;
@@ -209,7 +209,7 @@ main(int argc, char *argv[])
 
       ct = clock();
       plgriddata(x, y, z, pts, xg, xp, yg, yp, zg, alg, opt[alg-1]);
-      sprintf(xlab, "time=%d ms", (clock() - ct)/1000);
+      sprintf(xlab, "time=%ld ms", (clock() - ct)/1000);
       sprintf(ylab, "opt=%.3f", opt[alg-1]);
 
       /* - CSA can generate NaNs (only interpolates?!).
