@@ -1,4 +1,4 @@
-/* $Id: x22c.c,v 1.13 2005/10/07 18:25:51 airwin Exp $
+/* $Id: x22c.c,v 1.14 2006/05/27 21:05:09 hbabcock Exp $
 
     Simple vector plot example
     Copyright (C) 2004 Andrew Ross <andrewross@users.sourceforge.net>
@@ -160,7 +160,7 @@ constriction() {
 
 
 
-f2mnmx(PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmin, PLFLT *fmax)
+void f2mnmx(PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmin, PLFLT *fmax)
 {
     int i, j;
 
@@ -294,7 +294,6 @@ void potential() {
 int
 main(int argc, char *argv[])
 {
-    int i, j;
     PLINT narr, fill;
 
     /* Parse and process command line arguments */
