@@ -1,10 +1,11 @@
 //---------------------------------------------------------------------------//
-// $Id: x03.java,v 1.9 2004/01/17 16:41:39 rlaboiss Exp $
+// $Id: x03.java,v 1.15 2005/07/03 12:43:39 andrewross Exp $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
 // Copyright (C) 2001  Geoffrey Furnish
 // Copyright (C) 2001, 2002  Alan W. Irwin
+// Copyright (C) 2004  Andrew Ross
 //
 // This file is part of PLplot.
 //
@@ -19,7 +20,7 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -42,8 +43,7 @@ class x03 {
 
     public x03( String[] args )
     {
-       PLStreamc plsdummy = new PLStreamc();
-       plplotjavac pls = new plplotjavac();
+        PLStream pls = new PLStream();
         NumberFormat nf = NumberFormat.getNumberInstance();
 
         int i, j;
@@ -63,15 +63,15 @@ class x03 {
 
     // Parse and process command line arguments.
 
-        pls.plParseOpts( args, pls.PL_PARSE_FULL | pls.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
 
     // Initialize plplot.
 
-        pls.plinit();
+        pls.init();
 
     // Set up viewport and window, but do not draw box.
 
-        pls.plenv(-1.3, 1.3, -1.3, 1.3, 1, -2);
+        pls.env(-1.3, 1.3, -1.3, 1.3, 1, -2);
         for (i = 1; i <= 10; i++) {
             for (j = 0; j <= 360; j++) {
                 x[j] = 0.1 * i * x0[j];
@@ -80,10 +80,10 @@ class x03 {
 
         // Draw circles for polar grid.
 
-            pls.plline(x, y);
+            pls.line(x, y);
         }
 
-        pls.plcol0(2);
+        pls.col0(2);
         for (i = 0; i <= 11; i++) {
             theta = 30.0 * i;
             dx = Math.cos(dtr * theta);
@@ -91,16 +91,16 @@ class x03 {
 
         // Draw radial spokes for polar grid.
 
-            pls.pljoin(0.0, 0.0, dx, dy);
+            pls.join(0.0, 0.0, dx, dy);
             String text = nf.format(theta);
 
         // Write labels for angle.
 
 	//Slightly off zero to avoid floating point logic flips at 90 and 270 deg.
             if (dx >= -0.00001)
-                pls.plptex(dx, dy, dx, dy, -0.15, text);
+                pls.ptex(dx, dy, dx, dy, -0.15, text);
             else
-                pls.plptex(dx, dy, -dx, -dy, 1.15, text);
+                pls.ptex(dx, dy, -dx, -dy, 1.15, text);
         }
 
     // Draw the graph.
@@ -110,15 +110,15 @@ class x03 {
             x[i] = x0[i] * r;
             y[i] = y0[i] * r;
         }
-        pls.plcol0(3);
-        pls.plline(x, y);
+        pls.col0(3);
+        pls.line(x, y);
 
-        pls.plcol0(4);
-        pls.plmtex("t", 2.0, 0.5, 0.5, "#frPLplot Example 3 - r(#gh)=sin 5#gh");
+        pls.col0(4);
+        pls.mtex("t", 2.0, 0.5, 0.5, "#frPLplot Example 3 - r(#gh)=sin 5#gh");
 
     // Close the plot at end.
 
-        pls.plend();
+        pls.end();
     }
 }
 
