@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x11.java,v 1.20 2005/12/08 08:39:23 andrewross Exp $
+// $Id: x11.java,v 1.21 2006/05/12 23:24:02 airwin Exp $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -165,7 +165,7 @@ class x11 {
 	       
 	       /* magnitude colored wireframe plot with sides */
 	       else if (i==2)
-		 pls.plot3d(x, y, z, opt[k] | PLStream.MAG_COLOR, 1);
+		 pls.plot3d(x, y, z, opt[k] | PLStream.MAG_COLOR, true);
 	       
 	       /* magnitude colored wireframe plot with base contour */
 	       else if (i==3)
