@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x06.tcl,v 1.9 2001/12/22 21:20:18 airwin Exp $
+# $Id: x06.tcl,v 1.10 2005/01/20 23:38:55 airwin Exp $
 #----------------------------------------------------------------------------
 
 proc x06 {{w loopback}} {
@@ -18,7 +18,7 @@ proc x06 {{w loopback}} {
 
 # Draw the grid using plbox
 
-    $w cmd plbox "bcgt" 0.1 0 "bcgt" 0.1 0
+    $w cmd plbox "bcg" 0.1 0 "bcg" 0.1 0
 
 # Write the digits below the frame
 
