@@ -1,4 +1,4 @@
-/* $Id: plplotP.h,v 1.79 2004/05/19 22:51:09 airwin Exp $
+/* $Id: plplotP.h,v 1.94 2006/04/06 23:05:17 andrewross Exp $
 
     Internal (private) macros and prototypes for the PLplot package.  This
     header file must be included before all others, including system header
@@ -10,6 +10,9 @@
 
     Copyright (C) 2004  Rafael Laboissiere
     Copyright (C) 2004  Joao Cardoso
+    Copyright (C) 2004  Andrew Roach
+    Copyright (C) 2006  Andrew Ross
+
 
     This file is part of PLplot.
 
@@ -25,7 +28,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
 */
@@ -116,6 +119,12 @@ typedef char * caddr_t;
 #include <unistd.h>
 #endif
 
+/* (AM) Define M_PI if the platform does not include it
+   (MSVC for instance) */
+#if !defined(M_PI)
+#define M_PI 3.14159265358979323846
+#endif
+
 #if HAVE_DIRENT_H
 /* The following conditional is a workaround for a bug in the MacOSX system.
    When  the dirent.h file will be fixed upstream by Apple Inc, this should
@@ -240,7 +249,7 @@ extern PLStream	*plsc;
 
 #define PL_MAXPOLY	256	/* Max segments in polyline or polygon */
 #define PL_NSTREAMS	100	/* Max number of concurrent streams. */
-#define PL_RGB_COLOR	1<<7	/* A hack */
+#define PL_RGB_COLOR	-1	/* A hack */
 
 #define TEXT_MODE	0
 #define GRAPHICS_MODE	1
@@ -355,6 +364,30 @@ extern PLStream	*plsc;
 #define PLPLOT_TCL_ENV          "PLPLOT_TCL"
 #define PLPLOT_HOME_ENV         "PLPLOT_HOME"
 
+/*
+ *   Some stuff that is included (and compiled into) plsym.h
+ *   Other modules might want this, so we will "extern" it
+ *
+ */
+
+#ifndef __PLSYM_H__
+
+typedef struct {
+	unsigned int Hershey;
+	PLUNICODE Unicode;
+	char Font;
+} Hershey_to_Unicode_table;
+
+extern int number_of_entries_in_hershey_to_unicode_table;
+extern Hershey_to_Unicode_table hershey_to_unicode_lookup_table[];
+
+
+#endif
+
+/* Greek character translation array (defined in plcore.c) */
+extern const char plP_greek_mnemonic[];
+
+
 /*--------------------------------------------------------------------------*\
  *		Function Prototypes
  *
@@ -394,6 +427,14 @@ plP_plfclp(PLINT *x, PLINT *y, PLINT npts,
 int
 plP_clip_poly(int Ni, PLFLT *Vi[3], int axis, PLFLT dir, PLFLT offset);
 
+/* Stores hex digit value into FCI (font characterization integer). */
+void
+plP_hex2fci(unsigned char hexdigit, unsigned char hexpower, PLUNICODE *pfci);
+
+/* Retrieves hex digit value from FCI (font characterization integer). */
+void
+plP_fci2hex(PLUNICODE fci, unsigned char *phexdigit, unsigned char hexpower);
+
 /* Pattern fills in software the polygon bounded by the input points. */
 
 void
@@ -487,6 +528,10 @@ typedef struct {
   PLINT y;
   PLINT refx; /* processed ref. point--after justification, displacement, etc, processing */
   PLINT refy;
+  char font_face; /* font face OPTIONALLY used for rendering hershey codes */
+  PLUNICODE  unicode_char;   /* an int to hold either a Hershey, ASC-II, or Unicode value for plsym calls */
+  PLUNICODE  *unicode_array;   /* a pointer to an array of ints holding either a Hershey, ASC-II, or Unicode value for cached plsym */
+  unsigned short unicode_array_len;
   const char *string; /* text to draw */
 }EscText;
 
@@ -536,8 +581,8 @@ typedef struct cont_level {
 } CONT_LEVEL;
 
 void
-cont_store(PLFLT **f, PLINT nx, PLINT ny, 
-	    PLINT kx, PLINT lx, PLINT ky, PLINT ly, 
+cont_store(PLFLT **f, PLINT nx, PLINT ny,
+	    PLINT kx, PLINT lx, PLINT ky, PLINT ly,
 	    PLFLT *clevel, PLINT nlevel,
 	    void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 	    PLPointer pltr_data,
@@ -665,7 +710,7 @@ plP_stindex(const char *str1, const char *str2);
 /* Searches string str for first occurence of character chr.  */
 
 PLINT
-plP_strpos(char *str, int chr);
+plP_strpos(const char *str, int chr);
 
 /* Searches string str for character chr (case insensitive). */
 
@@ -898,6 +943,46 @@ plimageslow(short *x, short *y, unsigned short *data, PLINT nx, PLINT ny,
 typedef struct {
   PLFLT xmin, ymin, dx, dy;} IMG_DT;
 
+/*
+ * void plfvect()
+ *
+ * Internal routine to plot a vector array with arbitrary coordinate
+ * and vector transformations.
+ * This is not currently intended to be called direct by the user
+ */
+void plfvect(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
+		PLPointer f2evalv_data, PLPointer f2evalc_data,
+		PLINT nx, PLINT ny, PLFLT scale,
+		void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+		PLPointer pltr_data);
+
+/*
+ *  Internal function to get an index to the hershey table
+ */
+int
+plhershey2unicode ( int in );
+
+/* struct used for FCI to FontName lookups. */
+typedef struct
+{
+   PLUNICODE fci;
+   unsigned char *pfont;
+} FCI_to_FontName_Table;
+
+/* Internal function to obtain a pointer to a valid font name. */
+char *
+plP_FCI2FontName ( PLUNICODE fci,
+		   const FCI_to_FontName_Table lookup[], const int nlookup);
+
+
+/* Internal function to free memory from driver options */
+void
+plP_FreeDrvOpts();
+
+/* Convert a ucs4 unichar to utf8 char string*/
+int
+ucs4_to_utf8(PLUNICODE unichar, char *ptr);
+
 #ifdef __cplusplus
 }
 #endif
