@@ -6,13 +6,16 @@
 # This script must be run in the top plplot source directory as:
 #
 #     scripts/htdocs-gen_plot-examples.sh
-# 
-# The tarball will be copied to SourceForge and unpacked at the www area.  
+#
+# The tarball will be copied to SourceForge and unpacked at the www area.
 # If your user name (as given by the environment variable USER) is different
 # as that at SF, then launch the script like this:
-#     
+#
 #     WWW_USER=joeplplotter scripts/htdocs-gen_plot-examples.sh
 #
+# It is also possible to override the variables WWW_GROUP, WWW_HOST,
+# and WWW_DIR in the same way as with WWW_USER in the example above.
+#
 # To avoid rebuild launch it like this:
 #     build=false scripts/htdocs-gen_plot-examples.sh
 
@@ -27,7 +30,7 @@ if test "$build" = true; then
 
     ./configure --disable-static --enable-dyndrivers --prefix=/tmp/plplot \
     --disable-cxx --disable-python --disable-java --disable-itcl \
-    --disable-octave --enable-f77
+    --disable-octave --enable-f77 --enable-psttf --enable-psttfc
 
     make
     make install
@@ -43,10 +46,11 @@ rm -rf htdocs
 cp examples/c/lena.pgm .
 
 EXDIR=htdocs/examples-data
+TTFDIR=/usr/share/fonts/truetype
 
-for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 21 22 23 24; do
+for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 21 22 23 24 25; do
 
-    echo Working in example ${exe}
+    echo Working on example ${exe}
 
     # generate standard and preview size images
     if test $exe != 24 ; then
@@ -60,25 +64,20 @@ for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 21 22 23 24; do
         examples/c/x${exe}c -dev png -drvopt text,smooth=$SMOOTH \
 	    -o prev-x${exe} -fam -fflen 2 -geometry 200x150;
     else
-        ( export \
-	      PLPLOT_FREETYPE_SANS_FONT=/usr/share/fonts/truetype/arphic/bkai00mp.ttf \
-              PLPLOT_FREETYPE_SERIF_FONT=/usr/share/fonts/truetype/freefont/FreeSerif.ttf \
-              PLPLOT_FREETYPE_MONO_FONT=/usr/share/fonts/truetype/ttf-indic-fonts/lohit_hi.ttf \
-              PLPLOT_FREETYPE_SCRIPT_FONT=/usr/share/fonts/truetype/unfonts/UnBatang.ttf \
-              PLPLOT_FREETYPE_SYMBOL_FONT=/usr/share/fonts/truetype/ttf-bangla-fonts/JamrulNormal.ttf ; \
-          #examples/c/x24c -dev png -drvopt text,smooth=0 -o x24 -fam -fflen 2 ; \
-          #examples/c/x24c -dev png -drvopt text,smooth=0 -o prev-x24 \
-          #    -geometry 200x150 -fam -fflen 2 )
-	  # Temporary workaround for CTL problem with -dev png
-          examples/c/x24c -bg FFFFFF -dev psttfc -o test.ps ; \
-	  ps2eps --ignoreBB test.ps >| test.eps ; \
-	  convert -rotate 90 test.eps -geometry 800x600 x24.01.png ; \
-	  convert -rotate 90 test.eps -geometry 200x150 prev-x24.01.png ; \
-	  rm test.ps test.eps ; \
-	  #convert command needs the png suffix, but now take it off to
-	  #be consistent with script below which puts it back on again.
-	  mv x24.01.png x24.01 ; \
-	  mv prev-x24.01.png prev-x24.01 )
+      # Temporary workaround for CTL problem with -dev png
+      PLPLOT_FREETYPE_SANS_FONT=$TTFDIR/arphic/bkai00mp.ttf		    \
+      PLPLOT_FREETYPE_SERIF_FONT=$TTFDIR/freefont/FreeSerif.ttf 	    \
+      PLPLOT_FREETYPE_MONO_FONT=$TTFDIR/ttf-indic-fonts/lohit_hi.ttf	    \
+      PLPLOT_FREETYPE_SCRIPT_FONT=$TTFDIR/unfonts/UnBatang.ttf		    \
+      PLPLOT_FREETYPE_SYMBOL_FONT=$TTFDIR/ttf-bangla-fonts/JamrulNormal.ttf \
+      examples/c/x24c -dev psttfc -o test.ps
+      convert -rotate 90 test.ps -geometry 800x600 x24.01.png
+      convert -rotate 90 test.ps -geometry 200x150 prev-x24.01.png
+      rm test.ps
+      # convert command needs the png suffix, but now take it off to
+      # be consistent with script below which puts it back on again.
+      mv x24.01.png x24.01
+      mv prev-x24.01.png prev-x24.01
     fi
 
     # give png extension
@@ -90,18 +89,26 @@ for exe in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 21 22 23 24; do
     echo populating www directory demo${exe}
     mkdir -p $EXDIR/demo${exe}
     mv *${exe}.??.png $EXDIR/demo${exe}/
-    cp examples/c/x${exe}c.c examples/tcl/x${exe}.tcl               \
-       examples/java/x${exe}.java examples/f77/x${exe}f.f           \
-       bindings/octave/demos/x${exe}c.m	examples/python/xw${exe}.py \
-       examples/c++/x${exe}.cc 	examples/perl/x${exe}.pl            \
-       $EXDIR/demo${exe}
+    for f in examples/c/x${exe}c.c examples/tcl/x${exe}.tcl		\
+             examples/java/x${exe}.java examples/f77/x${exe}f.f		\
+             bindings/octave/demos/x${exe}c.m				\
+             examples/python/xw${exe}.py examples/c++/x${exe}.cc	\
+             examples/perl/x${exe}.pl ; do
+        if test -f $f ; then
+            cp $f $EXDIR/demo${exe}
+        else
+            echo Example `basename $f` is not yet available \
+                > $EXDIR/demo${exe}/`basename $f`
+        fi
+    done
 
-    # rename executables, to avoid browsers trying to execute files instead of showing them.
+    # rename executables, to avoid browsers trying to execute files
+    # instead of showing them.
     (cd  htdocs/examples-data/demo${exe};
     for j in *.c *.cc *.f *.m *.tcl *.java *.py *.pl; do
 	    mv $j $j-
     done
-    )  
+    )
 
 done
 
@@ -117,16 +124,22 @@ rm -rf htdocs
 # Transfer the tarball to Sourceforge and unpack it, such that the files will
 # appear in the PLplot web site
 
-WWW_HOST=${WWW_USER:+$WWW_USER@}shell.sf.net
-WWW_DIR=/home/groups/p/pl/plplot
+WWW_GROUP=${WWW_GROUP:-plplot}
+WWW_HOST=${WWW_HOST:-${WWW_USER:+$WWW_USER@}shell.sf.net}
+WWW_DIR=${WWW_DIR:-/home/groups/p/pl/plplot}
 
+echo Removing remote examples directory
+ssh $WWW_HOST rm -rf $WWW_DIR/$EXDIR
 echo Copying the tarball to WWW site
 scp $TARBALL $WWW_HOST:$WWW_DIR
 echo Changing its permission to allow group access
 ssh $WWW_HOST chmod g=u $WWW_DIR/$TARBALL
 echo Unpacking the remote tarball
 ssh $WWW_HOST tar -x -z -C $WWW_DIR -f $WWW_DIR/$TARBALL
-echo Changing its group permissions of the remote demo direcotry
+echo Changing group of the remote examples directory
+ssh $WWW_HOST chgrp -R $WWW_GROUP $WWW_DIR/$EXDIR
+echo Changing group permissions of the remote examples directory
 ssh $WWW_HOST chmod -R g=u $WWW_DIR/$EXDIR
 echo Removing the remote tarball
 ssh $WWW_HOST rm -f $WWW_DIR/$TARBALL
+ 
