@@ -23,7 +23,7 @@
 # along with PLplot; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-# $Id: make-cvs-tarball.sh,v 1.31 2006/04/25 01:58:38 hbabcock Exp $
+# $Id: make-cvs-tarball.sh,v 1.32 2006/05/16 01:46:52 hbabcock Exp $
 
 usage () {
   local prog=`basename $0`
@@ -46,7 +46,7 @@ usage () {
 
 DOC_ARG=${DOC_ARG:---enable-builddoc}
 WWW_USER=${WWW_USER:-hbabcock}
-CVSROOTDIR=${CVSROOTDIR:-cvs.sourceforge.net:/cvsroot/plplot}
+CVSROOTDIR=${CVSROOTDIR:-plplot.cvs.sourceforge.net:/cvsroot/plplot}
 VERSION=${VERSION:+--version=$1}
 BRANCH=${BRANCH:--D now}
 CVSTMPDIR=${CVSTMPDIR:-plplot-cvs-tarball}
