@@ -1,9 +1,10 @@
-/* $Id: plbuf.c,v 1.3 2004/01/31 06:39:53 airwin Exp $
+/* $Id: plbuf.c,v 1.10 2005/05/10 12:37:41 tomduck Exp $
 
     Handle plot buffer.
 
     Copyright (C) 1992  Maurice LeBrun
     Copyright (C) 2004  Alan W. Irwin
+    Copyright (C) 2005  Thomas J. Duck
 
     This file is part of PLplot.
 
@@ -19,7 +20,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #define NEED_PLDEBUG
@@ -189,12 +190,12 @@ plbuf_state(PLStream *pls, PLINT op)
     }
 
     case PLSTATE_COLOR0: {
-	U_CHAR icol0 = pls->icol0;
+	short icol0 = pls->icol0;
 	U_CHAR r = pls->curcolor.r;
 	U_CHAR g = pls->curcolor.g;
 	U_CHAR b = pls->curcolor.b;
 
-	fwrite(&icol0, sizeof(U_CHAR), 1, pls->plbufFile);
+	fwrite(&icol0, sizeof(short), 1, pls->plbufFile);
 	if (icol0 == PL_RGB_COLOR) {
 	    fwrite(&r, sizeof(U_CHAR), 1, pls->plbufFile);
 	    fwrite(&g, sizeof(U_CHAR), 1, pls->plbufFile);
@@ -204,9 +205,9 @@ plbuf_state(PLStream *pls, PLINT op)
     }
 
     case PLSTATE_COLOR1: {
-	U_CHAR icol1 = pls->icol1;
+	short icol1 = pls->icol1;
 
-	fwrite(&icol1, sizeof(U_CHAR), 1, pls->plbufFile);
+	fwrite(&icol1, sizeof(short), 1, pls->plbufFile);
 	break;
     }
 
@@ -250,6 +251,48 @@ plbuf_image(PLStream *pls, IMG_DT *img_dt)
     fwrite(pls->dev_z, sizeof(unsigned short), (pls->dev_nptsX-1)*(pls->dev_nptsY-1), pls->plbufFile);
 }
 
+/*--------------------------------------------------------------------------*\
+ * plbuf_text()
+ *
+ * Handle text call.
+\*--------------------------------------------------------------------------*/
+
+static void
+plbuf_text(PLStream *pls, EscText *text)
+{
+  PLINT n;
+  PLUNICODE fci;
+
+  dbug_enter("plbuf_text");
+  
+  /* Retrieve the font characterization integer */
+  plgfci(&fci);
+
+  /* Write the text information */
+
+  fwrite(&fci, sizeof(PLUNICODE), 1, pls->plbufFile);
+
+  fwrite(&pls->chrht, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(&pls->diorot, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(&pls->clpxmi, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(&pls->clpxma, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(&pls->clpymi, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(&pls->clpyma, sizeof(PLFLT), 1, pls->plbufFile);
+    
+  fwrite(&text->base, sizeof(PLINT), 1, pls->plbufFile);
+  fwrite(&text->just, sizeof(PLFLT), 1, pls->plbufFile);
+  fwrite(text->xform, sizeof(PLFLT), 4, pls->plbufFile);
+  fwrite(&text->x, sizeof(PLINT), 1, pls->plbufFile);
+  fwrite(&text->y, sizeof(PLINT), 1, pls->plbufFile);
+  fwrite(&text->refx, sizeof(PLINT), 1, pls->plbufFile);
+  fwrite(&text->refy, sizeof(PLINT), 1, pls->plbufFile);
+
+  fwrite(&text->unicode_array_len, sizeof(PLINT), 1, pls->plbufFile);
+  if(text->unicode_array_len)
+    fwrite(text->unicode_array, sizeof(PLUNICODE), 
+	   text->unicode_array_len, pls->plbufFile);
+}
+
 /*--------------------------------------------------------------------------*\
  * plbuf_esc()
  *
@@ -261,6 +304,7 @@ plbuf_image(PLStream *pls, IMG_DT *img_dt)
  *	PLESC_FILL	Fill polygon
  *	PLESC_SWIN	Set plot window parameters
  *      PLESC_IMAGE     Draw image
+ *      PLESC_HAS_TEXT  Draw PostScript text
 \*--------------------------------------------------------------------------*/
 
 void
@@ -281,6 +325,10 @@ plbuf_esc(PLStream *pls, PLINT op, void *ptr)
     case PLESC_IMAGE:
 	plbuf_image(pls, (IMG_DT *) ptr);
 	break;
+    case PLESC_HAS_TEXT:
+      if(ptr!=NULL) /* Check required by GCW driver, please don't remove */
+	  plbuf_text(pls, (EscText *) ptr);
+	break;
     }
 }
 
@@ -431,20 +479,21 @@ rdbuf_state(PLStream *pls)
     }
 
     case PLSTATE_COLOR0:{
-	U_CHAR icol0, r, g, b;
+	short icol0;
+	U_CHAR r, g, b;
 
-	fread(&icol0, sizeof(U_CHAR), 1, pls->plbufFile);
+	fread(&icol0, sizeof(short), 1, pls->plbufFile);
 	if (icol0 == PL_RGB_COLOR) {
 	    fread(&r, sizeof(U_CHAR), 1, pls->plbufFile);
 	    fread(&g, sizeof(U_CHAR), 1, pls->plbufFile);
 	    fread(&b, sizeof(U_CHAR), 1, pls->plbufFile);
 	}
 	else {
-	    if ((int) icol0 < 0 || (int) icol0 >= pls->ncol0) {
-	      char buffer[256];
-	      sprintf(buffer, "rdbuf_state: Invalid color map entry: %d", (int) icol0);
-	      plabort(buffer);
-	      return;
+	    if ((int) icol0 >= pls->ncol0) {
+                char buffer[256];
+                sprintf(buffer, "rdbuf_state: Invalid color map entry: %d", (int) icol0);
+                plabort(buffer);
+                return;
 	    }
 	    r = pls->cmap0[icol0].r;
 	    g = pls->cmap0[icol0].g;
@@ -460,9 +509,9 @@ rdbuf_state(PLStream *pls)
     }
 
     case PLSTATE_COLOR1: {
-	U_CHAR icol1;
+	short icol1;
 
-	fread(&icol1, sizeof(U_CHAR), 1, pls->plbufFile);
+	fread(&icol1, sizeof(short), 1, pls->plbufFile);
 
 	pls->icol1 = icol1;
 	pls->curcolor.r = pls->cmap1[icol1].r;
@@ -500,11 +549,15 @@ rdbuf_state(PLStream *pls)
  *	PLESC_FILL	Fill polygon
  *	PLESC_SWIN	Set plot window parameters
  *      PLESC_IMAGE     Draw image
+ *      PLESC_HAS_TEXT  Draw PostScript text
 \*--------------------------------------------------------------------------*/
 
 static void
 rdbuf_image(PLStream *pls);
 
+static void
+rdbuf_text(PLStream *pls);
+
 static void
 rdbuf_esc(PLStream *pls)
 {
@@ -524,6 +577,9 @@ rdbuf_esc(PLStream *pls)
     case PLESC_IMAGE:
 	rdbuf_image(pls);
 	break;
+    case PLESC_HAS_TEXT:
+        rdbuf_text(pls);
+	break;
     }
 }
 
@@ -557,10 +613,10 @@ rdbuf_fill(PLStream *pls)
 static void
 rdbuf_image(PLStream *pls)
 {
-  short *dev_ix, *dev_iy;
-  unsigned short *dev_z, dev_zmin, dev_zmax;
-  PLINT nptsX,nptsY, npts;
-  PLFLT xmin, ymin, dx, dy;
+    short *dev_ix, *dev_iy;
+    unsigned short *dev_z, dev_zmin, dev_zmax;
+    PLINT nptsX,nptsY, npts;
+    PLFLT xmin, ymin, dx, dy;
 
     dbug_enter("rdbuf_image");
 
@@ -615,6 +671,61 @@ rdbuf_swin(PLStream *pls)
     plP_swin(&plwin);
 }
 
+/*--------------------------------------------------------------------------*\
+ * rdbuf_text()
+ *
+ * Draw PostScript text.
+\*--------------------------------------------------------------------------*/
+
+static void
+rdbuf_text(PLStream *pls)
+{
+  PLUNICODE(fci);
+  EscText text;
+  PLFLT xform[4];
+  PLINT n;
+  PLUNICODE* unicode;
+
+  text.xform = xform;
+
+
+  /* Read in the data */
+
+  fread(&fci, sizeof(PLUNICODE), 1, pls->plbufFile);
+
+  fread(&pls->chrht, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(&pls->diorot, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(&pls->clpxmi, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(&pls->clpxma, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(&pls->clpymi, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(&pls->clpyma, sizeof(PLFLT), 1, pls->plbufFile);
+
+  fread(&text.base, sizeof(PLINT), 1, pls->plbufFile);
+  fread(&text.just, sizeof(PLFLT), 1, pls->plbufFile);
+  fread(text.xform, sizeof(PLFLT), 4, pls->plbufFile);
+  fread(&text.x, sizeof(PLINT), 1, pls->plbufFile);
+  fread(&text.y, sizeof(PLINT), 1, pls->plbufFile);
+  fread(&text.refx, sizeof(PLINT), 1, pls->plbufFile);
+  fread(&text.refy, sizeof(PLINT), 1, pls->plbufFile);
+
+  fread(&text.unicode_array_len, sizeof(PLINT), 1, pls->plbufFile);
+  if(text.unicode_array_len) {
+    if((unicode=(PLUNICODE *)malloc(text.unicode_array_len*sizeof(PLUNICODE)))
+       == NULL)
+      plexit("rdbuf_text: Insufficient memory");
+
+    fread(unicode, sizeof(PLUNICODE), text.unicode_array_len, pls->plbufFile);
+    text.unicode_array = unicode;
+  }
+  else text.unicode_array = NULL;
+
+  /* Make the call for unicode devices */
+  if(pls->dev_unicode) {
+    plsfci(fci);
+    plP_esc(PLESC_HAS_TEXT,&text);
+  }
+}
+
 /*--------------------------------------------------------------------------*\
  * plRemakePlot()
  *
