@@ -1,6 +1,6 @@
 /*
    plgridd.c: Plot grids data from irregularly sampled data.
-   $Id: plgridd.c,v 1.8 2004/01/17 16:41:40 rlaboiss Exp $
+   $Id: plgridd.c,v 1.10 2005/04/27 06:44:24 rlaboiss Exp $
 
    Copyright (C) 2004  Joao Cardoso
    Copyright (C) 2004  Alan W. Irwin
@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU Library General Public License
    along with PLplot; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 */
 
@@ -148,7 +148,8 @@ c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
 #ifdef WITH_CSA
     grid_csa(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #else
-    plabort("plgriddata(): PLplot was configured to not use GRID_CSA.");
+    plabort("plgriddata(): PLplot was configured to not use GRID_CSA.\n  Reverting to GRID_NNAIDW.");
+    grid_nnaidw(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #endif
     break;
 
@@ -168,7 +169,8 @@ c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
 #ifdef HAVE_QHULL
     grid_dtli(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #else
-    plabort("plgriddata(): you must have Qhull to use GRID_DTLI.");
+    plwarn("plgriddata(): you must have the Qhull library installed to use GRID_DTLI.\n  Reverting to GRID_NNAIDW.");
+    grid_nnaidw(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #endif
     break;
 
@@ -176,7 +178,8 @@ c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
 #ifdef HAVE_QHULL
     grid_nni(x, y, z, npts, xg, nptsx, yg, nptsy, zg, data);
 #else
-    plabort("plgriddata(): you must have Qhull to use GRID_NNI.");
+    plwarn("plgriddata(): you must have the Qhull library installed to use GRID_NNI.\n  Reverting to GRID_NNAIDW.");
+    grid_nnaidw(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #endif
     break;
 
