@@ -1,4 +1,4 @@
-/* $Id: plot3d.c,v 1.65 2005/04/27 06:44:25 rlaboiss Exp $
+/* $Id: plot3d.c,v 1.66 2006/05/12 23:53:41 airwin Exp $
 
 	3d plot routines.
 
@@ -723,9 +723,9 @@ c_plsurf3dl(PLFLT *x, PLFLT *y, PLFLT **z, PLINT nx, PLINT ny,
 
 void
 c_plot3d(PLFLT *x, PLFLT *y, PLFLT **z,
-	 PLINT nx, PLINT ny, PLINT opt, PLINT side)
+	 PLINT nx, PLINT ny, PLINT opt, PLBOOL side)
 {
-  c_plot3dc( x, y, z, nx, ny, opt | (side == 1 ? DRAW_SIDES : 0), NULL, 0);
+  c_plot3dc( x, y, z, nx, ny, opt | (side != 0 ? DRAW_SIDES : 0), NULL, 0);
 }
 
 /*--------------------------------------------------------------------------*\
