@@ -1,4 +1,4 @@
-/* $Id: plpage.c,v 1.27 2004/01/17 16:41:40 rlaboiss Exp $
+/* $Id: plpage.c,v 1.29 2005/04/27 06:44:25 rlaboiss Exp $
 
 	Page/subpage handling routines
 
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU Library General Public License
    along with PLplot; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #include "plplotP.h"
@@ -134,7 +134,7 @@ c_plbop(void)
 void
 plP_subpInit(void)
 {
-    PLFLT scale, size_chr, size_sym, size_maj, size_min;
+    PLFLT scale, size_chr, size_sym, size_maj, size_min, theta, rat;
 
 /* Subpage checks */
 
@@ -158,6 +158,16 @@ plP_subpInit(void)
 	((plsc->phyxma - plsc->phyxmi) / plsc->xpmm +
 	 (plsc->phyyma - plsc->phyymi) / plsc->ypmm) / 200.0;
 
+    /* Take account of scaling caused by change of orientation */
+    if (plsc->difilt && PLDI_ORI) {
+      theta = 0.5*M_PI*plsc->diorot;
+      rat = ( (plsc->phyxma - plsc->phyxmi) / plsc->xpmm ) / 
+	( (plsc->phyyma - plsc->phyymi) / plsc->ypmm );
+      rat = MAX(rat,1.0/rat);
+      rat = fabs(cos(theta)) + rat*fabs(sin(theta));
+      scale /= rat;
+    }
+
     if (plsc->nsuby > 1)
 	scale /= sqrt((double) plsc->nsuby);
 
