@@ -7,7 +7,7 @@ void *h_pldll;
 
 extern "C" int APIENTRY
   DllMain(HINSTANCE hInstance,DWORD dwReason,LPVOID lpReserved) {
-  
+
   if (dwReason == DLL_PROCESS_ATTACH) {
 //          MessageBox(NULL,"dll init","TDLL",MB_OK);
 	  h_pldll = hInstance;
@@ -30,17 +30,31 @@ extern "C" {
 
 /* Advance to subpage "page", or to the next one if "page" = 0. */
 
-void WINAPI 
+void WINAPI
 pladv(PLINT page) {
 	c_pladv(page);
 }
 
+/* Allocate a 2D grid */
+
+void WINAPI
+win_plAlloc2dGrid(PLFLT ***f, PLINT nx, PLINT ny) {
+	plAlloc2dGrid(f, nx, ny);
+}
+
+/* Frees a block of memory allocated with plAlloc2dGrid(). */
+
+void WINAPI
+win_plFree2dGrid(PLFLT **f, PLINT nx, PLINT ny) {
+	plFree2dGrid(f, nx, ny);
+}
+
 /* This functions similarly to plbox() except that the origin of the axes */
 /* is placed at the user-specified point (x0, y0). */
 
 void WINAPI
-plaxes(PLFLT x0, PLFLT y0, const char *xopt, PLFLT xtick, 
-	   PLINT nxsub, const char *yopt, PLFLT ytick, 
+plaxes(PLFLT x0, PLFLT y0, const char *xopt, PLFLT xtick,
+	   PLINT nxsub, const char *yopt, PLFLT ytick,
 	   PLINT nysub) {
 	c_plaxes(x0,y0,xopt,xtick,nxsub,yopt,ytick,nysub);
 }
@@ -93,7 +107,7 @@ plcol1(PLFLT col1) {
 }
 
 /* Draws a contour plot from data in f(nx,ny).  Is just a front-end to
- * plfcont, with a particular choice for f2eval and f2eval_data. 
+ * plfcont, with a particular choice for f2eval and f2eval_data.
  */
 
 void WINAPI
@@ -412,7 +426,7 @@ plot3d(PLFLT *x, PLFLT *y, PLFLT **z,
 
 int WINAPI
 win_plParseOpts(int *p_argc, char **argv, PLINT mode) {
-    return plParseOpts(p_argc, argv, mode) ;
+    return c_plparseopts(p_argc, argv, mode) ;
 }
 
 /* Set fill pattern directly. */
@@ -617,7 +631,7 @@ plsfnam(const char *fnam) {
 }
 
 /* Shade region. */
-typedef int  DefineFuncPtr( PLFLT, PLFLT ) ;
+typedef long  DefineFuncPtr( PLFLT, PLFLT ) ;
 typedef void *FillFuncPtr(PLINT, PLFLT *, PLFLT *) ;
 typedef void *PlotFuncPtr(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer) ;
 
@@ -629,7 +643,7 @@ plshade(PLFLT **a, PLINT nx, PLINT ny, DefineFuncPtr defined,
 	  PLINT min_color, PLINT min_width,
 	  PLINT max_color, PLINT max_width,
 	  FillFuncPtr fill, PLINT rectangular, PlotFuncPtr pltr,
-	  PLPointer pltr_data) { 
+	  PLPointer pltr_data) {
 	c_plshade(a,nx,ny,defined,
 		left,right,bottom,top,
 		shade_min,shade_max,
@@ -742,6 +756,11 @@ plstyl(PLINT nms, PLINT *mark, PLINT *space) {
 	c_plstyl(nms,mark,space);
 }
 
+void WINAPI
+plsvect(PLFLT *arrowx, PLFLT *arrowy, PLINT npts, PLINT fill) {
+	c_plsvect(arrowx, arrowy, npts, fill);
+}
+
 /* Sets the edges of the viewport to the specified absolute coordinates */
 
 void WINAPI
@@ -784,6 +803,12 @@ pltext(void) {
 	c_pltext();
 }
 
+void WINAPI plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+              void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+              PLPointer pltr_data) {
+	c_plvect(u, v, nx, ny, scale, pltr, pltr_data);
+}
+
 /* Sets the edges of the viewport with the given aspect ratio, leaving */
 /* room for labels. */
 
