@@ -1,4 +1,4 @@
-/* $Id: plrender.c,v 1.66 2004/06/14 21:51:58 rlaboiss Exp $
+/* $Id: plrender.c,v 1.70 2005/04/27 06:44:27 rlaboiss Exp $
 
     Copyright 1991, 1992, 1993, 1994, 1995
     Geoffrey Furnish			furnish@dino.ph.utexas.edu
@@ -23,7 +23,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -32,9 +32,10 @@
     the metafile driver, plmeta.c.
 */
 
-char ident[] = "@(#) $Id: plrender.c,v 1.66 2004/06/14 21:51:58 rlaboiss Exp $";
+char ident[] = "@(#) $Id: plrender.c,v 1.70 2005/04/27 06:44:27 rlaboiss Exp $";
 
 #define DEBUG
+#define DEBUG_ENTER
 
 #define NEED_PLDEBUG
 #include "plplotP.h"
@@ -157,6 +158,11 @@ static PLFLT	dev_xpmm, dev_ypmm;
 static PLINT	dev_xmin, dev_xmax, dev_ymin, dev_ymax, dev_xlen, dev_ylen;
 static PLFLT	vpxmin, vpxmax, vpxlen, vpymin, vpymax, vpylen;
 
+/* Geometry info */
+
+static float    xdpi, ydpi;
+static PLINT    xlength, ylength, xoffset, yoffset;
+
 /* Miscellaneous */
 
 static U_CHAR 	c_old, c1;
@@ -359,10 +365,10 @@ ProcessFile(int argc, char **argv)
     plsstrm(1);
 
 /* Process plrender and PLplot (internal) command line options */
-/* Since we aren't using full parsing, plParseOpts() will stop when it hits */
+/* Since we aren't using full parsing, plparseopts() will stop when it hits */
 /* a non-flag item */
 
-    if (plParseOpts(&argc, argv, 0))
+    if (plparseopts(&argc, argv, 0))
 	exit(1);
 
 /* Any remaining flags are illegal. */
@@ -407,7 +413,7 @@ ProcessFile(int argc, char **argv)
     for (i = 0; i < argc; i++) {
 	argv[i] = myargv[i];
     }
-    (void) plParseOpts(&argc, argv, 0);
+    (void) plparseopts(&argc, argv, 0);
 
 /* Miscellaneous housekeeping */
 
@@ -641,6 +647,7 @@ process_next(U_CHAR c)
 static void
 plr_init(U_CHAR c)
 {
+    int debug=0;
     PLFLT aspect, dev_aspect, ratio;
 
     dbug_enter("plr_init");
@@ -649,6 +656,10 @@ plr_init(U_CHAR c)
 
     plsKeyEH(plr_KeyEH, NULL);
 
+/* Note: many drivers ignore these, needed to preserve the aspect ratio */
+
+    plspage( xdpi, ydpi, xlength, ylength, xoffset, yoffset );
+
 /* Start up PLplot */
 
     plinit();
@@ -661,6 +672,10 @@ plr_init(U_CHAR c)
 
     aspect = (ylen / pxly) / (xlen / pxlx);
 
+    if (debug)
+        printf( "xlen %d pxlx %f ylen %d pxly %f\n",
+                xlen, pxlx, ylen, pxly );
+
 /* Aspect ratio of output device */
 
     plP_gphy(&dev_xmin, &dev_xmax, &dev_ymin, &dev_ymax);
@@ -669,6 +684,10 @@ plr_init(U_CHAR c)
     dev_xlen = dev_xmax - dev_xmin;
     dev_ylen = dev_ymax - dev_ymin;
 
+    if (debug)
+        printf( "dev_xlen %d dev_xpmm %f dev_ylen %d dev_ypmm %f\n",
+                dev_xlen, dev_xpmm, dev_ylen, dev_ypmm );
+
     dev_aspect = (dev_ylen / dev_ypmm) / (dev_xlen / dev_xpmm);
 
     if (dev_aspect <= 0.)
@@ -676,6 +695,10 @@ plr_init(U_CHAR c)
 
     ratio = aspect / dev_aspect;
 
+    if (debug)
+        printf( "ratio %f aspect %f dev_aspect %f\n",
+                ratio, aspect, dev_aspect );
+
 /* Default relative coordinate space */
 
     vpxlen = 1.0;
@@ -691,6 +714,7 @@ plr_init(U_CHAR c)
  * plots to come out correctly.  Note: this could also be done using the
  * driver interface function plsdimap.
  */
+
     if (ratio <= 0)
 	fprintf(stderr, "Aspect ratio error: ratio = %f\n", ratio);
     else if (ratio < 1)
@@ -704,6 +728,10 @@ plr_init(U_CHAR c)
     vpymin = (1. - vpylen) / 2.;
     vpymax = vpymin + vpylen;
 
+    if (debug)
+        printf( "vpxmin %f vpxmax %f vpymin %f vpymax %f\n",
+                vpxmin, vpxmax, vpymin, vpymax );
+
 /* Seek to first page */
 
     cursub = nsubx*nsuby;
@@ -886,13 +914,31 @@ plr_state(U_CHAR op)
     }
 
     case PLSTATE_COLOR0:{
-	U_SHORT icol;
-	U_CHAR icol0, r, g, b;
+	if (strcmp(mf_version, "2005a") >= 0)
+        {
+            short icol0;
+	    plm_rd( pdf_rd_2bytes(pdfs, &icol0) );
 
-	if (strcmp(mf_version, "1993a") >= 0) {
+	    if (icol0 == PL_RGB_COLOR)
+            {
+                U_CHAR r, g, b;
+		plm_rd( pdf_rd_1byte(pdfs, &r) );
+		plm_rd( pdf_rd_1byte(pdfs, &g) );
+		plm_rd( pdf_rd_1byte(pdfs, &b) );
+		plrgb1(r, g, b);
+	    }
+	    else {
+		plcol(icol0);
+	    }
+        }
+	else if (strcmp(mf_version, "1993a") >= 0)
+        {
+            U_CHAR icol0;
 	    plm_rd( pdf_rd_1byte(pdfs, &icol0) );
 
-	    if (icol0 == PL_RGB_COLOR) {
+	    if (icol0 == 1<<7)
+            {
+                U_CHAR r, g, b;
 		plm_rd( pdf_rd_1byte(pdfs, &r) );
 		plm_rd( pdf_rd_1byte(pdfs, &g) );
 		plm_rd( pdf_rd_1byte(pdfs, &b) );
@@ -902,7 +948,9 @@ plr_state(U_CHAR op)
 		plcol(icol0);
 	    }
 	}
-	else {
+	else
+        {
+            U_SHORT icol;
 	    plm_rd( pdf_rd_2bytes(pdfs, &icol) );
 	    plcol(icol);
 	}
@@ -928,10 +976,18 @@ plr_state(U_CHAR op)
     }
 
     case PLSTATE_CMAP0:{
-	U_CHAR ncol0;
-
-	plm_rd(pdf_rd_1byte(pdfs, &ncol0));
-	plscmap0n(ncol0);
+	if (strcmp(mf_version, "2005a") >= 0)
+        {
+            U_SHORT ncol0;
+            plm_rd(pdf_rd_2bytes(pdfs, &ncol0));
+            plscmap0n(ncol0);
+        }
+        else
+        {
+            U_CHAR ncol0;
+            plm_rd(pdf_rd_1byte(pdfs, &ncol0));
+            plscmap0n(ncol0);
+        }
 	for (i = 0; i < plsc->ncol0; i++) {
 	    plm_rd(pdf_rd_1byte(pdfs, &plsc->cmap0[i].r));
 	    plm_rd(pdf_rd_1byte(pdfs, &plsc->cmap0[i].g));
@@ -1703,6 +1759,7 @@ ReadFileHeader(void)
 	fprintf(stderr, "Please obtain a newer copy of plrender.\n");
 	return 1;
     }
+    pldebug( "ReadFileHeader", "Metafile version %s\n", mf_version );
 
 /* Disable page seeking on versions without page links */
 
@@ -1772,6 +1829,42 @@ ReadFileHeader(void)
 	    continue;
 	}
 
+    /* Geometry info */
+
+	if ( ! strcmp(tag, "xdpi")) {
+	    plm_rd( pdf_rd_ieeef(pdfs, &xdpi) );
+	    continue;
+	}
+
+	if ( ! strcmp(tag, "ydpi")) {
+	    plm_rd( pdf_rd_ieeef(pdfs, &ydpi) );
+	    continue;
+	}
+
+	if ( ! strcmp(tag, "xlength")) {
+	    plm_rd( pdf_rd_2bytes(pdfs, &dum_ushort) );
+	    xlength = dum_ushort;
+	    continue;
+	}
+
+	if ( ! strcmp(tag, "ylength")) {
+	    plm_rd( pdf_rd_2bytes(pdfs, &dum_ushort) );
+	    ylength = dum_ushort;
+	    continue;
+	}
+
+	if ( ! strcmp(tag, "xoffset")) {
+	    plm_rd( pdf_rd_2bytes(pdfs, &dum_ushort) );
+	    xoffset = dum_ushort;
+	    continue;
+	}
+
+	if ( ! strcmp(tag, "yoffset")) {
+	    plm_rd( pdf_rd_2bytes(pdfs, &dum_ushort) );
+	    yoffset = dum_ushort;
+	    continue;
+	}
+
     /* Obsolete tags */
 
 	if ( ! strcmp(tag, "orient")) {
